@@ -75,7 +75,10 @@ virBhyveDomainCapsFill(virDomainCapsPtr caps,
                        unsigned int bhyvecaps,
                        virDomainCapsStringValuesPtr firmwares)
 {
-    caps->disk.supported = true;
+    caps->disk.supported = VIR_TRISTATE_BOOL_YES;
+    caps->disk.diskDevice.report = true;
+    caps->disk.bus.report = true;
+    caps->disk.model.report = true;
     VIR_DOMAIN_CAPS_ENUM_SET(caps->disk.diskDevice,
                              VIR_DOMAIN_DISK_DEVICE_DISK,
                              VIR_DOMAIN_DISK_DEVICE_CDROM);
@@ -84,10 +87,13 @@ virBhyveDomainCapsFill(virDomainCapsPtr caps,
                              VIR_DOMAIN_DISK_BUS_SATA,
                              VIR_DOMAIN_DISK_BUS_VIRTIO);
 
-    caps->os.supported = true;
+    caps->os.supported = VIR_TRISTATE_BOOL_YES;
 
+    caps->os.loader.supported = VIR_TRISTATE_BOOL_NO;
     if (bhyvecaps & BHYVE_CAP_LPC_BOOTROM) {
-        caps->os.loader.supported = true;
+        caps->os.loader.type.report = true;
+        caps->os.loader.readonly.report = true;
+        caps->os.loader.supported = VIR_TRISTATE_BOOL_YES;
         VIR_DOMAIN_CAPS_ENUM_SET(caps->os.loader.type,
                                  VIR_DOMAIN_LOADER_TYPE_PFLASH);
         VIR_DOMAIN_CAPS_ENUM_SET(caps->os.loader.readonly,
@@ -98,12 +104,23 @@ virBhyveDomainCapsFill(virDomainCapsPtr caps,
     }
 
 
+    caps->graphics.supported = VIR_TRISTATE_BOOL_NO;
+    caps->video.supported = VIR_TRISTATE_BOOL_NO;
     if (bhyvecaps & BHYVE_CAP_FBUF) {
-        caps->graphics.supported = true;
-        caps->video.supported = true;
+        caps->graphics.supported = VIR_TRISTATE_BOOL_YES;
+        caps->graphics.type.report = true;
+        caps->video.supported = VIR_TRISTATE_BOOL_YES;
+        caps->video.modelType.report = true;
         VIR_DOMAIN_CAPS_ENUM_SET(caps->graphics.type, VIR_DOMAIN_GRAPHICS_TYPE_VNC);
         VIR_DOMAIN_CAPS_ENUM_SET(caps->video.modelType, VIR_DOMAIN_VIDEO_TYPE_GOP);
     }
+
+    caps->hostdev.supported = VIR_TRISTATE_BOOL_NO;
+    caps->iothreads = VIR_TRISTATE_BOOL_NO;
+    caps->vmcoreinfo = VIR_TRISTATE_BOOL_NO;
+    caps->genid = VIR_TRISTATE_BOOL_NO;
+    caps->gic.supported = VIR_TRISTATE_BOOL_NO;
+
     return 0;
 }
 
