@@ -25,6 +25,7 @@
 #include "virlog.h"
 #include "virstring.h"
 #include "bhyve_conf.h"
+#include "bhyve_domain.h"
 #include "configmake.h"
 
 #define VIR_FROM_THIS VIR_FROM_BHYVE
@@ -42,7 +43,7 @@ static int virBhyveConfigOnceInit(void)
     return 0;
 }
 
-VIR_ONCE_GLOBAL_INIT(virBhyveConfig)
+VIR_ONCE_GLOBAL_INIT(virBhyveConfig);
 
 virBhyveDriverConfigPtr
 virBhyveDriverConfigNew(void)
@@ -107,3 +108,18 @@ virBhyveDriverConfigDispose(void *obj)
 
     VIR_FREE(cfg->firmwareDir);
 }
+
+void
+bhyveDomainCmdlineDefFree(bhyveDomainCmdlineDefPtr def)
+{
+    size_t i;
+
+    if (!def)
+        return;
+
+    for (i = 0; i < def->num_args; i++)
+        VIR_FREE(def->args[i]);
+
+    VIR_FREE(def->args);
+    VIR_FREE(def);
+}
