@@ -32,35 +32,41 @@
 
 VIR_LOG_INIT("conf.cpu_conf");
 
-VIR_ENUM_IMPL(virCPU, VIR_CPU_TYPE_LAST,
+VIR_ENUM_IMPL(virCPU,
+              VIR_CPU_TYPE_LAST,
               "host", "guest", "auto",
 );
 
-VIR_ENUM_IMPL(virCPUMode, VIR_CPU_MODE_LAST,
+VIR_ENUM_IMPL(virCPUMode,
+              VIR_CPU_MODE_LAST,
               "custom",
               "host-model",
               "host-passthrough",
 );
 
-VIR_ENUM_IMPL(virCPUMatch, VIR_CPU_MATCH_LAST,
+VIR_ENUM_IMPL(virCPUMatch,
+              VIR_CPU_MATCH_LAST,
               "minimum",
               "exact",
               "strict",
 );
 
-VIR_ENUM_IMPL(virCPUCheck, VIR_CPU_CHECK_LAST,
+VIR_ENUM_IMPL(virCPUCheck,
+              VIR_CPU_CHECK_LAST,
               "default",
               "none",
               "partial",
               "full",
 );
 
-VIR_ENUM_IMPL(virCPUFallback, VIR_CPU_FALLBACK_LAST,
+VIR_ENUM_IMPL(virCPUFallback,
+              VIR_CPU_FALLBACK_LAST,
               "allow",
               "forbid",
 );
 
-VIR_ENUM_IMPL(virCPUFeaturePolicy, VIR_CPU_FEATURE_LAST,
+VIR_ENUM_IMPL(virCPUFeaturePolicy,
+              VIR_CPU_FEATURE_LAST,
               "force",
               "require",
               "optional",
@@ -68,7 +74,8 @@ VIR_ENUM_IMPL(virCPUFeaturePolicy, VIR_CPU_FEATURE_LAST,
               "forbid",
 );
 
-VIR_ENUM_IMPL(virCPUCacheMode, VIR_CPU_CACHE_MODE_LAST,
+VIR_ENUM_IMPL(virCPUCacheMode,
+              VIR_CPU_CACHE_MODE_LAST,
               "emulate",
               "passthrough",
               "disable",
@@ -887,6 +894,13 @@ virCPUDefIsEqual(virCPUDefPtr src,
         goto cleanup;
     }
 
+    if (src->check != dst->check) {
+        MISMATCH(_("Target CPU check %s does not match source %s"),
+                 virCPUCheckTypeToString(dst->check),
+                 virCPUCheckTypeToString(src->check));
+        goto cleanup;
+    }
+
     if (src->arch != dst->arch) {
         MISMATCH(_("Target CPU arch %s does not match source %s"),
                  virArchToString(dst->arch),
