@@ -27,7 +27,8 @@
 
 #define VIR_FROM_THIS VIR_FROM_CAPABILITIES
 
-VIR_ENUM_IMPL(virDomainCapsCPUUsable, VIR_DOMCAPS_CPU_USABLE_LAST,
+VIR_ENUM_IMPL(virDomainCapsCPUUsable,
+              VIR_DOMCAPS_CPU_USABLE_LAST,
               "unknown", "yes", "no",
 );
 
@@ -415,6 +416,7 @@ virDomainCapsLoaderFormat(virBufferPtr buf,
     virDomainCapsStringValuesFormat(buf, &loader->values);
     ENUM_PROCESS(loader, type, virDomainLoaderTypeToString);
     ENUM_PROCESS(loader, readonly, virTristateBoolTypeToString);
+    ENUM_PROCESS(loader, secure, virTristateBoolTypeToString);
 
     FORMAT_EPILOGUE(loader);
 }
@@ -427,6 +429,8 @@ virDomainCapsOSFormat(virBufferPtr buf,
 
     FORMAT_PROLOGUE(os);
 
+    ENUM_PROCESS(os, firmware, virDomainOsDefFirmwareTypeToString);
+
     virDomainCapsLoaderFormat(buf, loader);
 
     FORMAT_EPILOGUE(os);
