@@ -18,12 +18,10 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library.  If not, see
  * <http://www.gnu.org/licenses/>.
- *
- * Author: Daniel P. Berrange <berrange@redhat.com>
  */
 
-#ifndef __VIRDOMAINOBJLIST_H__
-# define __VIRDOMAINOBJLIST_H__
+#ifndef LIBVIRT_VIRDOMAINOBJLIST_H
+# define LIBVIRT_VIRDOMAINOBJLIST_H
 
 # include "domain_conf.h"
 
@@ -152,4 +150,4 @@ int virDomainObjListConvert(virDomainObjListPtr domlist,
                             unsigned int flags,
                             bool skip_missing);
 
-#endif /* __VIRDOMAINOBJLIST_H__ */
+#endif /* LIBVIRT_VIRDOMAINOBJLIST_H */
