@@ -26,8 +26,8 @@
 
 extern struct cpuArchDriver cpuDriverX86;
 
-int virCPUx86DataAddCPUID(virCPUDataPtr cpuData,
-                          const virCPUx86CPUID *cpuid);
+int virCPUx86DataAdd(virCPUDataPtr cpuData,
+                     const virCPUx86DataItem *cpuid);
 
 int virCPUx86DataSetSignature(virCPUDataPtr cpuData,
                               unsigned int family,
