@@ -16,12 +16,10 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library;  If not, see
  * <http://www.gnu.org/licenses/>.
- *
- * Author: Daniel P. Berrange <berrange@redhat.com>
  */
 
-#ifndef __VIR_LOG_DAEMON_H__
-# define __VIR_LOG_DAEMON_H__
+#ifndef LIBVIRT_LOG_DAEMON_H
+# define LIBVIRT_LOG_DAEMON_H
 
 # include "virthread.h"
 # include "log_handler.h"
@@ -42,4 +40,4 @@ extern virLogDaemonPtr logDaemon;
 
 virLogHandlerPtr virLogDaemonGetHandler(virLogDaemonPtr dmn);
 
-#endif /* __VIR_LOG_DAEMON_H__ */
+#endif /* LIBVIRT_LOG_DAEMON_H */
