@@ -88,6 +88,9 @@ qemuBlockNodeNameBackingChainDataFree(qemuBlockNodeNameBackingChainDataPtr data)
     VIR_FREE(data);
 }
 
+VIR_DEFINE_AUTOPTR_FUNC(qemuBlockNodeNameBackingChainData,
+                        qemuBlockNodeNameBackingChainDataFree);
+
 
 static void
 qemuBlockNodeNameBackingChainDataHashEntryFree(void *opaque,
@@ -128,7 +131,7 @@ qemuBlockNodeNameGetBackingChainBacking(virJSONValuePtr next,
                                         virHashTablePtr nodenamestable,
                                         qemuBlockNodeNameBackingChainDataPtr *nodenamedata)
 {
-    qemuBlockNodeNameBackingChainDataPtr data = NULL;
+    VIR_AUTOPTR(qemuBlockNodeNameBackingChainData) data = NULL;
     qemuBlockNodeNameBackingChainDataPtr backingdata = NULL;
     virJSONValuePtr backing = virJSONValueObjectGetObject(next, "backing");
     virJSONValuePtr parent = virJSONValueObjectGetObject(next, "parent");
@@ -139,7 +142,6 @@ qemuBlockNodeNameGetBackingChainBacking(virJSONValuePtr next,
     const char *drvparent = NULL;
     const char *parentnodename = NULL;
     const char *filename = NULL;
-    int ret = -1;
 
     if (!nodename)
         return 0;
@@ -169,28 +171,24 @@ qemuBlockNodeNameGetBackingChainBacking(virJSONValuePtr next,
     }
 
     if (VIR_ALLOC(data) < 0)
-        goto cleanup;
+        return -1;
 
     if (VIR_STRDUP(data->nodeformat, nodename) < 0 ||
         VIR_STRDUP(data->nodestorage, parentnodename) < 0 ||
         VIR_STRDUP(data->qemufilename, filename) < 0 ||
         VIR_STRDUP(data->drvformat, drvname) < 0 ||
         VIR_STRDUP(data->drvstorage, drvparent) < 0)
-        goto cleanup;
+        return -1;
 
     if (backing &&
         qemuBlockNodeNameGetBackingChainBacking(backing, nodenamestable,
                                                 &backingdata) < 0)
-        goto cleanup;
+        return -1;
 
     VIR_STEAL_PTR(data->backing, backingdata);
     VIR_STEAL_PTR(*nodenamedata, data);
 
-    ret = 0;
-
- cleanup:
-    qemuBlockNodeNameBackingChainDataFree(data);
-    return ret;
+    return 0;
 }
 
 
@@ -201,24 +199,18 @@ qemuBlockNodeNameGetBackingChainDisk(size_t pos ATTRIBUTE_UNUSED,
 {
     struct qemuBlockNodeNameGetBackingChainData *data = opaque;
     const char *device = virJSONValueObjectGetString(item, "device");
-    qemuBlockNodeNameBackingChainDataPtr devicedata = NULL;
-    int ret = -1;
+    VIR_AUTOPTR(qemuBlockNodeNameBackingChainData) devicedata = NULL;
 
     if (qemuBlockNodeNameGetBackingChainBacking(item, data->nodenamestable,
                                                 &devicedata) < 0)
-        goto cleanup;
+        return -1;
 
     if (devicedata &&
         virHashAddEntry(data->disks, device, devicedata) < 0)
-        goto cleanup;
+        return -1;
 
     devicedata = NULL;
-    ret = 1; /* we don't really want to steal @item */
-
- cleanup:
-    qemuBlockNodeNameBackingChainDataFree(devicedata);
-
-    return ret;
+    return 1; /* we don't really want to steal @item */
 }
 
 
@@ -240,22 +232,21 @@ qemuBlockNodeNameGetBackingChain(virJSONValuePtr namednodes,
                                  virJSONValuePtr blockstats)
 {
     struct qemuBlockNodeNameGetBackingChainData data;
-    virHashTablePtr namednodestable = NULL;
-    virHashTablePtr disks = NULL;
-    virHashTablePtr ret = NULL;
+    VIR_AUTOPTR(virHashTable) namednodestable = NULL;
+    VIR_AUTOPTR(virHashTable) disks = NULL;
 
     memset(&data, 0, sizeof(data));
 
     if (!(namednodestable = virHashCreate(50, virJSONValueHashFree)))
-        goto cleanup;
+        return NULL;
 
     if (virJSONValueArrayForeachSteal(namednodes,
                                       qemuBlockNamedNodesArrayToHash,
                                       namednodestable) < 0)
-        goto cleanup;
+        return NULL;
 
     if (!(disks = virHashCreate(50, qemuBlockNodeNameBackingChainDataHashEntryFree)))
-        goto cleanup;
+        return NULL;
 
     data.nodenamestable = namednodestable;
     data.disks = disks;
@@ -263,15 +254,9 @@ qemuBlockNodeNameGetBackingChain(virJSONValuePtr namednodes,
     if (virJSONValueArrayForeachSteal(blockstats,
                                       qemuBlockNodeNameGetBackingChainDisk,
                                       &data) < 0)
-        goto cleanup;
+        return NULL;
 
-    VIR_STEAL_PTR(ret, disks);
-
- cleanup:
-     virHashFree(namednodestable);
-     virHashFree(disks);
-
-     return ret;
+    VIR_RETURN_PTR(disks);
 }
 
 
@@ -295,7 +280,7 @@ qemuBlockDiskDetectNodes(virDomainDiskDefPtr disk,
 {
     qemuBlockNodeNameBackingChainDataPtr entry = NULL;
     virStorageSourcePtr src = disk->src;
-    char *alias = NULL;
+    VIR_AUTOFREE(char *) alias = NULL;
     int ret = -1;
 
     /* don't attempt the detection if the top level already has node names */
@@ -330,7 +315,6 @@ qemuBlockDiskDetectNodes(virDomainDiskDefPtr disk,
     ret = 0;
 
  cleanup:
-    VIR_FREE(alias);
     if (ret < 0)
         qemuBlockDiskClearDetectedNodes(disk);
 
@@ -344,12 +328,11 @@ qemuBlockNodeNamesDetect(virQEMUDriverPtr driver,
                          qemuDomainAsyncJob asyncJob)
 {
     qemuDomainObjPrivatePtr priv = vm->privateData;
-    virHashTablePtr disktable = NULL;
-    virJSONValuePtr data = NULL;
-    virJSONValuePtr blockstats = NULL;
+    VIR_AUTOPTR(virHashTable) disktable = NULL;
+    VIR_AUTOPTR(virJSONValue) data = NULL;
+    VIR_AUTOPTR(virJSONValue) blockstats = NULL;
     virDomainDiskDefPtr disk;
     size_t i;
-    int ret = -1;
 
     if (!virQEMUCapsGet(priv->qemuCaps, QEMU_CAPS_QUERY_NAMED_BLOCK_NODES))
         return 0;
@@ -361,26 +344,19 @@ qemuBlockNodeNamesDetect(virQEMUDriverPtr driver,
     blockstats = qemuMonitorQueryBlockstats(qemuDomainGetMonitor(vm));
 
     if (qemuDomainObjExitMonitor(driver, vm) < 0 || !data || !blockstats)
-        goto cleanup;
+        return -1;
 
     if (!(disktable = qemuBlockNodeNameGetBackingChain(data, blockstats)))
-        goto cleanup;
+        return -1;
 
     for (i = 0; i < vm->def->ndisks; i++) {
         disk = vm->def->disks[i];
 
         if (qemuBlockDiskDetectNodes(disk, disktable) < 0)
-            goto cleanup;
+            return -1;
     }
 
-    ret = 0;
-
- cleanup:
-    virJSONValueFree(data);
-    virJSONValueFree(blockstats);
-    virHashFree(disktable);
-
-    return ret;
+    return 0;
 }
 
 
@@ -396,20 +372,16 @@ qemuBlockNodeNamesDetect(virQEMUDriverPtr driver,
 virHashTablePtr
 qemuBlockGetNodeData(virJSONValuePtr data)
 {
-    virHashTablePtr ret = NULL;
+    VIR_AUTOPTR(virHashTable) nodedata = NULL;
 
-    if (!(ret = virHashCreate(50, virJSONValueHashFree)))
+    if (!(nodedata = virHashCreate(50, virJSONValueHashFree)))
         return NULL;
 
     if (virJSONValueArrayForeachSteal(data,
-                                      qemuBlockNamedNodesArrayToHash, ret) < 0)
-        goto error;
+                                      qemuBlockNamedNodesArrayToHash, nodedata) < 0)
+        return NULL;
 
-    return ret;
-
- error:
-    virHashFree(ret);
-    return NULL;
+    VIR_RETURN_PTR(nodedata);
 }
 
 
@@ -437,53 +409,48 @@ qemuBlockStorageSourceSupportsConcurrentAccess(virStorageSourcePtr src)
 virURIPtr
 qemuBlockStorageSourceGetURI(virStorageSourcePtr src)
 {
-    virURIPtr uri = NULL;
-    virURIPtr ret = NULL;
+    VIR_AUTOPTR(virURI) uri = NULL;
 
     if (src->nhosts != 1) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
                        _("protocol '%s' accepts only one host"),
                        virStorageNetProtocolTypeToString(src->protocol));
-        goto cleanup;
+        return NULL;
     }
 
     if (VIR_ALLOC(uri) < 0)
-        goto cleanup;
+        return NULL;
 
     if (src->hosts->transport == VIR_STORAGE_NET_HOST_TRANS_TCP) {
         uri->port = src->hosts->port;
 
         if (VIR_STRDUP(uri->scheme,
                        virStorageNetProtocolTypeToString(src->protocol)) < 0)
-            goto cleanup;
+            return NULL;
     } else {
         if (virAsprintf(&uri->scheme, "%s+%s",
                         virStorageNetProtocolTypeToString(src->protocol),
                         virStorageNetHostTransportTypeToString(src->hosts->transport)) < 0)
-            goto cleanup;
+            return NULL;
     }
 
     if (src->path) {
         if (src->volume) {
             if (virAsprintf(&uri->path, "/%s/%s",
                             src->volume, src->path) < 0)
-                goto cleanup;
+                return NULL;
         } else {
             if (virAsprintf(&uri->path, "%s%s",
                             src->path[0] == '/' ? "" : "/",
                             src->path) < 0)
-                goto cleanup;
+                return NULL;
         }
     }
 
     if (VIR_STRDUP(uri->server, src->hosts->name) < 0)
-        goto cleanup;
+        return NULL;
 
-    VIR_STEAL_PTR(ret, uri);
-
- cleanup:
-    virURIFree(uri);
-    return ret;
+    VIR_RETURN_PTR(uri);
 }
 
 
@@ -504,11 +471,10 @@ static virJSONValuePtr
 qemuBlockStorageSourceBuildJSONSocketAddress(virStorageNetHostDefPtr host,
                                              bool legacy)
 {
-    virJSONValuePtr server = NULL;
-    virJSONValuePtr ret = NULL;
+    VIR_AUTOPTR(virJSONValue) server = NULL;
     const char *transport;
     const char *field;
-    char *port = NULL;
+    VIR_AUTOFREE(char *) port = NULL;
 
     switch ((virStorageNetHostTransport) host->transport) {
     case VIR_STORAGE_NET_HOST_TRANS_TCP:
@@ -518,14 +484,14 @@ qemuBlockStorageSourceBuildJSONSocketAddress(virStorageNetHostDefPtr host,
             transport = "inet";
 
         if (virAsprintf(&port, "%u", host->port) < 0)
-            goto cleanup;
+            return NULL;
 
         if (virJSONValueObjectCreate(&server,
                                      "s:type", transport,
                                      "s:host", host->name,
                                      "s:port", port,
                                      NULL) < 0)
-            goto cleanup;
+            return NULL;
         break;
 
     case VIR_STORAGE_NET_HOST_TRANS_UNIX:
@@ -538,7 +504,7 @@ qemuBlockStorageSourceBuildJSONSocketAddress(virStorageNetHostDefPtr host,
                                      "s:type", "unix",
                                      field, host->socket,
                                      NULL) < 0)
-            goto cleanup;
+            return NULL;
         break;
 
     case VIR_STORAGE_NET_HOST_TRANS_RDMA:
@@ -546,16 +512,10 @@ qemuBlockStorageSourceBuildJSONSocketAddress(virStorageNetHostDefPtr host,
         virReportError(VIR_ERR_INTERNAL_ERROR,
                        _("transport protocol '%s' is not yet supported"),
                        virStorageNetHostTransportTypeToString(host->transport));
-        goto cleanup;
+        return NULL;
     }
 
-    VIR_STEAL_PTR(ret, server);
-
- cleanup:
-    VIR_FREE(port);
-    virJSONValueFree(server);
-
-    return ret;
+    VIR_RETURN_PTR(server);
 }
 
 
@@ -571,34 +531,27 @@ static virJSONValuePtr
 qemuBlockStorageSourceBuildHostsJSONSocketAddress(virStorageSourcePtr src,
                                                   bool legacy)
 {
-    virJSONValuePtr servers = NULL;
-    virJSONValuePtr server = NULL;
-    virJSONValuePtr ret = NULL;
+    VIR_AUTOPTR(virJSONValue) servers = NULL;
+    VIR_AUTOPTR(virJSONValue) server = NULL;
     virStorageNetHostDefPtr host;
     size_t i;
 
     if (!(servers = virJSONValueNewArray()))
-        goto cleanup;
+        return NULL;
 
     for (i = 0; i < src->nhosts; i++) {
         host = src->hosts + i;
 
         if (!(server = qemuBlockStorageSourceBuildJSONSocketAddress(host, legacy)))
-              goto cleanup;
+              return NULL;
 
         if (virJSONValueArrayAppend(servers, server) < 0)
-            goto cleanup;
+            return NULL;
 
         server = NULL;
     }
 
-    VIR_STEAL_PTR(ret, servers);
-
- cleanup:
-    virJSONValueFree(servers);
-    virJSONValueFree(server);
-
-    return ret;
+    VIR_RETURN_PTR(servers);
 }
 
 
@@ -615,7 +568,7 @@ static virJSONValuePtr
 qemuBlockStorageSourceBuildJSONInetSocketAddress(virStorageNetHostDefPtr host)
 {
     virJSONValuePtr ret = NULL;
-    char *port = NULL;
+    VIR_AUTOFREE(char *) port = NULL;
 
     if (host->transport != VIR_STORAGE_NET_HOST_TRANS_TCP) {
         virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
@@ -631,7 +584,6 @@ qemuBlockStorageSourceBuildJSONInetSocketAddress(virStorageNetHostDefPtr host)
                                           "s:port", port,
                                           NULL));
 
-    VIR_FREE(port);
     return ret;
 }
 
@@ -646,34 +598,27 @@ qemuBlockStorageSourceBuildJSONInetSocketAddress(virStorageNetHostDefPtr host)
 static virJSONValuePtr
 qemuBlockStorageSourceBuildHostsJSONInetSocketAddress(virStorageSourcePtr src)
 {
-    virJSONValuePtr servers = NULL;
-    virJSONValuePtr server = NULL;
-    virJSONValuePtr ret = NULL;
+    VIR_AUTOPTR(virJSONValue) servers = NULL;
+    VIR_AUTOPTR(virJSONValue) server = NULL;
     virStorageNetHostDefPtr host;
     size_t i;
 
     if (!(servers = virJSONValueNewArray()))
-        goto cleanup;
+        return NULL;
 
     for (i = 0; i < src->nhosts; i++) {
         host = src->hosts + i;
 
         if (!(server = qemuBlockStorageSourceBuildJSONInetSocketAddress(host)))
-            goto cleanup;
+            return NULL;
 
         if (virJSONValueArrayAppend(servers, server) < 0)
-            goto cleanup;
+            return NULL;
 
         server = NULL;
     }
 
-    VIR_STEAL_PTR(ret, servers);
-
- cleanup:
-    virJSONValueFree(servers);
-    virJSONValueFree(server);
-
-    return ret;
+    VIR_RETURN_PTR(servers);
 }
 
 
@@ -681,9 +626,8 @@ static virJSONValuePtr
 qemuBlockStorageSourceGetGlusterProps(virStorageSourcePtr src,
                                       bool legacy)
 {
-    virJSONValuePtr servers = NULL;
-    virJSONValuePtr props = NULL;
-    virJSONValuePtr ret = NULL;
+    VIR_AUTOPTR(virJSONValue) servers = NULL;
+    VIR_AUTOPTR(virJSONValue) props = NULL;
 
     if (!(servers = qemuBlockStorageSourceBuildHostsJSONSocketAddress(src, legacy)))
         return NULL;
@@ -699,19 +643,13 @@ qemuBlockStorageSourceGetGlusterProps(virStorageSourcePtr src,
                                  "s:volume", src->volume,
                                  "s:path", src->path,
                                  "a:server", &servers, NULL) < 0)
-        goto cleanup;
+        return NULL;
 
     if (src->debug &&
         virJSONValueObjectAdd(props, "u:debug", src->debugLevel, NULL) < 0)
-        goto cleanup;
+        return NULL;
 
-    VIR_STEAL_PTR(ret, props);
-
- cleanup:
-    virJSONValueFree(servers);
-    virJSONValueFree(props);
-
-    return ret;
+    VIR_RETURN_PTR(props);
 }
 
 
@@ -719,7 +657,7 @@ static virJSONValuePtr
 qemuBlockStorageSourceGetVxHSProps(virStorageSourcePtr src)
 {
     const char *protocol = virStorageNetProtocolTypeToString(src->protocol);
-    virJSONValuePtr server = NULL;
+    VIR_AUTOPTR(virJSONValue) server = NULL;
     virJSONValuePtr ret = NULL;
 
     if (src->nhosts != 1) {
@@ -737,12 +675,11 @@ qemuBlockStorageSourceGetVxHSProps(virStorageSourcePtr src)
      *   vdisk-id:"eb90327c-8302-4725-4e85ed4dc251",
      *   server:{type:"tcp", host:"1.2.3.4", port:9999}}
      */
-    if (virJSONValueObjectCreate(&ret,
-                                 "s:driver", protocol,
-                                 "S:tls-creds", src->tlsAlias,
-                                 "s:vdisk-id", src->path,
-                                 "a:server", &server, NULL) < 0)
-        virJSONValueFree(server);
+    ignore_value(virJSONValueObjectCreate(&ret,
+                                          "s:driver", protocol,
+                                          "S:tls-creds", src->tlsAlias,
+                                          "s:vdisk-id", src->path,
+                                          "a:server", &server, NULL));
 
     return ret;
 }
@@ -755,8 +692,8 @@ qemuBlockStorageSourceGetCURLProps(virStorageSourcePtr src)
     const char *passwordalias = NULL;
     const char *username = NULL;
     virJSONValuePtr ret = NULL;
-    virURIPtr uri = NULL;
-    char *uristr = NULL;
+    VIR_AUTOPTR(virURI) uri = NULL;
+    VIR_AUTOFREE(char *) uristr = NULL;
     const char *driver;
 
     /**
@@ -774,10 +711,10 @@ qemuBlockStorageSourceGetCURLProps(virStorageSourcePtr src)
     driver = virStorageNetProtocolTypeToString(src->protocol);
 
     if (!(uri = qemuBlockStorageSourceGetURI(src)))
-        goto cleanup;
+        return NULL;
 
     if (!(uristr = virURIFormat(uri)))
-        goto cleanup;
+        return NULL;
 
     if (src->auth) {
         username = src->auth->username;
@@ -791,10 +728,6 @@ qemuBlockStorageSourceGetCURLProps(virStorageSourcePtr src)
                                           "S:password-secret", passwordalias,
                                           NULL));
 
- cleanup:
-    virURIFree(uri);
-    VIR_FREE(uristr);
-
     return ret;
 }
 
@@ -804,11 +737,11 @@ qemuBlockStorageSourceGetISCSIProps(virStorageSourcePtr src)
 {
     qemuDomainStorageSourcePrivatePtr srcPriv = QEMU_DOMAIN_STORAGE_SOURCE_PRIVATE(src);
     const char *protocol = virStorageNetProtocolTypeToString(src->protocol);
-    char *target = NULL;
+    VIR_AUTOFREE(char *) target = NULL;
     char *lunStr = NULL;
     char *username = NULL;
     char *objalias = NULL;
-    char *portal = NULL;
+    VIR_AUTOFREE(char *) portal = NULL;
     unsigned int lun = 0;
     virJSONValuePtr ret = NULL;
 
@@ -824,7 +757,7 @@ qemuBlockStorageSourceGetISCSIProps(virStorageSourcePtr src)
      */
 
     if (VIR_STRDUP(target, src->path) < 0)
-        goto cleanup;
+        return NULL;
 
     /* Separate the target and lun */
     if ((lunStr = strchr(target, '/'))) {
@@ -833,7 +766,7 @@ qemuBlockStorageSourceGetISCSIProps(virStorageSourcePtr src)
             virReportError(VIR_ERR_INTERNAL_ERROR,
                            _("cannot parse target for lunStr '%s'"),
                            target);
-            goto cleanup;
+            return NULL;
         }
     }
 
@@ -841,11 +774,11 @@ qemuBlockStorageSourceGetISCSIProps(virStorageSourcePtr src)
     if (virSocketAddrNumericFamily(src->hosts[0].name) == AF_INET6) {
         if (virAsprintf(&portal, "[%s]:%u",
                         src->hosts[0].name, src->hosts[0].port) < 0)
-            goto cleanup;
+            return NULL;
     } else {
         if (virAsprintf(&portal, "%s:%u",
                         src->hosts[0].name, src->hosts[0].port) < 0)
-            goto cleanup;
+            return NULL;
     }
 
     if (src->auth) {
@@ -863,11 +796,6 @@ qemuBlockStorageSourceGetISCSIProps(virStorageSourcePtr src)
                                           "S:password-secret", objalias,
                                           "S:initiator-name", src->initiator.iqn,
                                           NULL));
-        goto cleanup;
-
- cleanup:
-    VIR_FREE(target);
-    VIR_FREE(portal);
     return ret;
 }
 
@@ -875,7 +803,7 @@ qemuBlockStorageSourceGetISCSIProps(virStorageSourcePtr src)
 static virJSONValuePtr
 qemuBlockStorageSourceGetNBDProps(virStorageSourcePtr src)
 {
-    virJSONValuePtr serverprops;
+    VIR_AUTOPTR(virJSONValue) serverprops = NULL;
     virJSONValuePtr ret = NULL;
 
     if (src->nhosts != 1) {
@@ -895,10 +823,8 @@ qemuBlockStorageSourceGetNBDProps(virStorageSourcePtr src)
                                  "S:export", src->path,
                                  "S:tls-creds", src->tlsAlias,
                                  NULL) < 0)
-        goto cleanup;
+        return NULL;
 
- cleanup:
-    virJSONValueFree(serverprops);
     return ret;
 }
 
@@ -907,11 +833,11 @@ static virJSONValuePtr
 qemuBlockStorageSourceGetRBDProps(virStorageSourcePtr src)
 {
     qemuDomainStorageSourcePrivatePtr srcPriv = QEMU_DOMAIN_STORAGE_SOURCE_PRIVATE(src);
-    virJSONValuePtr servers = NULL;
+    VIR_AUTOPTR(virJSONValue) servers = NULL;
     virJSONValuePtr ret = NULL;
     const char *username = NULL;
-    virJSONValuePtr authmodes = NULL;
-    virJSONValuePtr mode = NULL;
+    VIR_AUTOPTR(virJSONValue) authmodes = NULL;
+    VIR_AUTOPTR(virJSONValue) mode = NULL;
     const char *keysecret = NULL;
 
     if (src->nhosts > 0 &&
@@ -923,17 +849,17 @@ qemuBlockStorageSourceGetRBDProps(virStorageSourcePtr src)
         keysecret = srcPriv->secinfo->s.aes.alias;
         /* the auth modes are modelled after our old command line generator */
         if (!(authmodes = virJSONValueNewArray()))
-            goto cleanup;
+            return NULL;
 
         if (!(mode = virJSONValueNewString("cephx")) ||
             virJSONValueArrayAppend(authmodes, mode) < 0)
-            goto cleanup;
+            return NULL;
 
         mode = NULL;
 
         if (!(mode = virJSONValueNewString("none")) ||
             virJSONValueArrayAppend(authmodes, mode) < 0)
-            goto cleanup;
+            return NULL;
 
         mode = NULL;
     }
@@ -949,12 +875,8 @@ qemuBlockStorageSourceGetRBDProps(virStorageSourcePtr src)
                                  "A:auth-client-required", &authmodes,
                                  "S:key-secret", keysecret,
                                  NULL) < 0)
-        goto cleanup;
+        return NULL;
 
- cleanup:
-    virJSONValueFree(authmodes);
-    virJSONValueFree(mode);
-    virJSONValueFree(servers);
     return ret;
 }
 
@@ -962,7 +884,7 @@ qemuBlockStorageSourceGetRBDProps(virStorageSourcePtr src)
 static virJSONValuePtr
 qemuBlockStorageSourceGetSheepdogProps(virStorageSourcePtr src)
 {
-    virJSONValuePtr serverprops;
+    VIR_AUTOPTR(virJSONValue) serverprops = NULL;
     virJSONValuePtr ret = NULL;
 
     if (src->nhosts != 1) {
@@ -982,10 +904,8 @@ qemuBlockStorageSourceGetSheepdogProps(virStorageSourcePtr src)
                                  "a:server", &serverprops,
                                  "s:vdi", src->path,
                                  NULL) < 0)
-        goto cleanup;
+        return NULL;
 
- cleanup:
-    virJSONValueFree(serverprops);
     return ret;
 }
 
@@ -993,7 +913,7 @@ qemuBlockStorageSourceGetSheepdogProps(virStorageSourcePtr src)
 static virJSONValuePtr
 qemuBlockStorageSourceGetSshProps(virStorageSourcePtr src)
 {
-    virJSONValuePtr serverprops;
+    VIR_AUTOPTR(virJSONValue) serverprops = NULL;
     virJSONValuePtr ret = NULL;
     const char *username = NULL;
 
@@ -1016,10 +936,8 @@ qemuBlockStorageSourceGetSshProps(virStorageSourcePtr src)
                                  "a:server", &serverprops,
                                  "S:user", username,
                                  NULL) < 0)
-        goto cleanup;
+        return NULL;
 
- cleanup:
-    virJSONValueFree(serverprops);
     return ret;
 }
 
@@ -1078,7 +996,7 @@ static int
 qemuBlockStorageSourceGetBlockdevGetCacheProps(virStorageSourcePtr src,
                                                virJSONValuePtr props)
 {
-    virJSONValuePtr cacheobj;
+    VIR_AUTOPTR(virJSONValue) cacheobj = NULL;
     bool direct = false;
     bool noflush = false;
 
@@ -1094,10 +1012,9 @@ qemuBlockStorageSourceGetBlockdevGetCacheProps(virStorageSourcePtr src,
                                  NULL) < 0)
         return -1;
 
-    if (virJSONValueObjectAppend(props, "cache", cacheobj) < 0) {
-        virJSONValueFree(cacheobj);
+    if (virJSONValueObjectAppend(props, "cache", cacheobj) < 0)
         return -1;
-    }
+    cacheobj = NULL;
 
     return 0;
 }
@@ -1116,8 +1033,7 @@ qemuBlockStorageSourceGetBackendProps(virStorageSourcePtr src,
                                       bool legacy)
 {
     int actualType = virStorageSourceGetActualType(src);
-    virJSONValuePtr fileprops = NULL;
-    virJSONValuePtr ret = NULL;
+    VIR_AUTOPTR(virJSONValue) fileprops = NULL;
 
     switch ((virStorageType)actualType) {
     case VIR_STORAGE_TYPE_BLOCK:
@@ -1193,24 +1109,20 @@ qemuBlockStorageSourceGetBackendProps(virStorageSourcePtr src,
 
     if (qemuBlockNodeNameValidate(src->nodestorage) < 0 ||
         virJSONValueObjectAdd(fileprops, "S:node-name", src->nodestorage, NULL) < 0)
-        goto cleanup;
+        return NULL;
 
     if (!legacy) {
         if (qemuBlockStorageSourceGetBlockdevGetCacheProps(src, fileprops) < 0)
-            goto cleanup;
+            return NULL;
 
         if (virJSONValueObjectAdd(fileprops,
                                   "b:read-only", src->readonly,
                                   "s:discard", "unmap",
                                   NULL) < 0)
-            goto cleanup;
+            return NULL;
     }
 
-    VIR_STEAL_PTR(ret, fileprops);
-
- cleanup:
-    virJSONValueFree(fileprops);
-    return ret;
+    VIR_RETURN_PTR(fileprops);
 }
 
 
@@ -1292,8 +1204,7 @@ qemuBlockStorageSourceGetFormatQcowGenericProps(virStorageSourcePtr src,
                                                 const char *format,
                                                 virJSONValuePtr props)
 {
-    virJSONValuePtr encprops = NULL;
-    int ret = -1;
+    VIR_AUTOPTR(virJSONValue) encprops = NULL;
 
     if (qemuBlockStorageSourceGetCryptoProps(src, &encprops) < 0)
         return -1;
@@ -1301,13 +1212,9 @@ qemuBlockStorageSourceGetFormatQcowGenericProps(virStorageSourcePtr src,
     if (virJSONValueObjectAdd(props,
                               "s:driver", format,
                               "A:encrypt", &encprops, NULL) < 0)
-        goto cleanup;
+        return -1;
 
-    ret = 0;
-
- cleanup:
-    virJSONValueFree(encprops);
-    return ret;
+    return 0;
 }
 
 
@@ -1342,8 +1249,7 @@ qemuBlockStorageSourceGetBlockdevFormatCommonProps(virStorageSourcePtr src)
     const char *discard = NULL;
     int detectZeroesMode = virDomainDiskGetDetectZeroesMode(src->discard,
                                                             src->detect_zeroes);
-    virJSONValuePtr props = NULL;
-    virJSONValuePtr ret = NULL;
+    VIR_AUTOPTR(virJSONValue) props = NULL;
 
     if (qemuBlockNodeNameValidate(src->nodeformat) < 0)
         return NULL;
@@ -1367,13 +1273,9 @@ qemuBlockStorageSourceGetBlockdevFormatCommonProps(virStorageSourcePtr src)
         return NULL;
 
     if (qemuBlockStorageSourceGetBlockdevGetCacheProps(src, props) < 0)
-        goto cleanup;
+        return NULL;
 
-    VIR_STEAL_PTR(ret, props);
-
- cleanup:
-    virJSONValueFree(props);
-    return ret;
+    VIR_RETURN_PTR(props);
 }
 
 
@@ -1381,11 +1283,10 @@ static virJSONValuePtr
 qemuBlockStorageSourceGetBlockdevFormatProps(virStorageSourcePtr src)
 {
     const char *driver = NULL;
-    virJSONValuePtr props = NULL;
-    virJSONValuePtr ret = NULL;
+    VIR_AUTOPTR(virJSONValue) props = NULL;
 
     if (!(props = qemuBlockStorageSourceGetBlockdevFormatCommonProps(src)))
-        goto cleanup;
+        return NULL;
 
     switch ((virStorageFileFormat) src->format) {
     case VIR_STORAGE_FILE_FAT:
@@ -1393,17 +1294,17 @@ qemuBlockStorageSourceGetBlockdevFormatProps(virStorageSourcePtr src)
          * put a raw layer on top */
     case VIR_STORAGE_FILE_RAW:
         if (qemuBlockStorageSourceGetFormatRawProps(src, props) < 0)
-            goto cleanup;
+            return NULL;
         break;
 
     case VIR_STORAGE_FILE_QCOW2:
         if (qemuBlockStorageSourceGetFormatQcow2Props(src, props) < 0)
-            goto cleanup;
+            return NULL;
         break;
 
     case VIR_STORAGE_FILE_QCOW:
         if (qemuBlockStorageSourceGetFormatQcowGenericProps(src, "qcow", props) < 0)
-            goto cleanup;
+            return NULL;
         break;
 
     /* formats without any special parameters */
@@ -1434,24 +1335,19 @@ qemuBlockStorageSourceGetBlockdevFormatProps(virStorageSourcePtr src)
         virReportError(VIR_ERR_INTERNAL_ERROR,
                        _("mishandled storage format '%s'"),
                        virStorageFileFormatTypeToString(src->format));
-        goto cleanup;
+        return NULL;
 
     case VIR_STORAGE_FILE_LAST:
     default:
         virReportEnumRangeError(virStorageFileFormat, src->format);
-        goto cleanup;
+        return NULL;
     }
 
     if (driver &&
         virJSONValueObjectAdd(props, "s:driver", driver, NULL) < 0)
-        goto cleanup;
+        return NULL;
 
-    VIR_STEAL_PTR(ret, props);
-
- cleanup:
-    virJSONValueFree(props);
-
-    return ret;
+    VIR_RETURN_PTR(props);
 }
 
 
@@ -1468,40 +1364,35 @@ virJSONValuePtr
 qemuBlockStorageSourceGetBlockdevProps(virStorageSourcePtr src)
 {
     bool backingSupported = src->format >= VIR_STORAGE_FILE_BACKING;
-    virJSONValuePtr props = NULL;
-    virJSONValuePtr ret = NULL;
+    VIR_AUTOPTR(virJSONValue) props = NULL;
 
     if (virStorageSourceHasBacking(src) && !backingSupported) {
         virReportError(VIR_ERR_CONFIG_UNSUPPORTED,
                        _("storage format '%s' does not support backing store"),
                        virStorageFileFormatTypeToString(src->format));
-        goto cleanup;
+        return NULL;
     }
 
     if (!(props = qemuBlockStorageSourceGetBlockdevFormatProps(src)))
-        goto cleanup;
+        return NULL;
 
     if (virJSONValueObjectAppendString(props, "file", src->nodestorage) < 0)
-        goto cleanup;
+        return NULL;
 
     if (src->backingStore && backingSupported) {
         if (virStorageSourceHasBacking(src)) {
             if (virJSONValueObjectAppendString(props, "backing",
                                                src->backingStore->nodeformat) < 0)
-                goto cleanup;
+                return NULL;
         } else {
             /* chain is terminated, indicate that no detection should happen
              * in qemu */
             if (virJSONValueObjectAppendNull(props, "backing") < 0)
-                goto cleanup;
+                return NULL;
         }
     }
 
-    VIR_STEAL_PTR(ret, props);
-
- cleanup:
-    virJSONValueFree(props);
-    return ret;
+    VIR_RETURN_PTR(props);
 }
 
 
@@ -1543,24 +1434,19 @@ qemuBlockStorageSourceAttachDataFree(qemuBlockStorageSourceAttachDataPtr data)
 qemuBlockStorageSourceAttachDataPtr
 qemuBlockStorageSourceAttachPrepareBlockdev(virStorageSourcePtr src)
 {
-    qemuBlockStorageSourceAttachDataPtr data;
-    qemuBlockStorageSourceAttachDataPtr ret = NULL;
+    VIR_AUTOPTR(qemuBlockStorageSourceAttachData) data = NULL;
 
     if (VIR_ALLOC(data) < 0)
         return NULL;
 
     if (!(data->formatProps = qemuBlockStorageSourceGetBlockdevProps(src)) ||
         !(data->storageProps = qemuBlockStorageSourceGetBackendProps(src, false)))
-        goto cleanup;
+        return NULL;
 
     data->storageNodeName = src->nodestorage;
     data->formatNodeName = src->nodeformat;
 
-    VIR_STEAL_PTR(ret, data);
-
- cleanup:
-    qemuBlockStorageSourceAttachDataFree(data);
-    return ret;
+    VIR_RETURN_PTR(data);
 }
 
 
@@ -1720,15 +1606,14 @@ qemuBlockSnapshotAddLegacy(virJSONValuePtr actions,
                            bool reuse)
 {
     const char *format = virStorageFileFormatTypeToString(newsrc->format);
-    char *device = NULL;
-    char *source = NULL;
-    int ret = -1;
+    VIR_AUTOFREE(char *) device = NULL;
+    VIR_AUTOFREE(char *) source = NULL;
 
     if (!(device = qemuAliasDiskDriveFromDisk(disk)))
-        goto cleanup;
+        return -1;
 
     if (qemuGetDriveSourceString(newsrc, NULL, &source) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorJSONTransactionAdd(actions, "blockdev-snapshot-sync",
                                       "s:device", device,
@@ -1736,14 +1621,9 @@ qemuBlockSnapshotAddLegacy(virJSONValuePtr actions,
                                       "s:format", format,
                                       "S:mode", reuse ? "existing" : NULL,
                                       NULL) < 0)
-        goto cleanup;
+        return -1;
 
-    ret = 0;
-
- cleanup:
-    VIR_FREE(device);
-    VIR_FREE(source);
-    return ret;
+    return 0;
 }
 
 
