@@ -71,13 +71,12 @@ struct _qemuBlockJobData {
 
     virDomainDiskDefPtr disk; /* may be NULL, if blockjob does not correspond to any disk */
 
-    bool started;
     int type; /* qemuBlockJobType */
     int state; /* qemuBlockjobState */
     char *errmsg;
     bool synchronous; /* API call is waiting for this job */
 
-    int newstate; /* virConnectDomainEventBlockJobStatus - new state to be processed */
+    int newstate; /* qemuBlockjobState, subset of events emitted by qemu */
 };
 
 
