@@ -770,14 +770,21 @@ int qemuDomainDiskGetBackendAlias(virDomainDiskDefPtr disk,
     ATTRIBUTE_NONNULL(1) ATTRIBUTE_NONNULL(2)
     ATTRIBUTE_NONNULL(3) ATTRIBUTE_RETURN_CHECK;
 
-void qemuDomainDiskChainElementRevoke(virQEMUDriverPtr driver,
-                                      virDomainObjPtr vm,
-                                      virStorageSourcePtr elem);
-int qemuDomainDiskChainElementPrepare(virQEMUDriverPtr driver,
-                                      virDomainObjPtr vm,
-                                      virStorageSourcePtr elem,
-                                      bool readonly,
-                                      bool newSource);
+int qemuDomainStorageSourceChainAccessAllow(virQEMUDriverPtr driver,
+                                            virDomainObjPtr vm,
+                                            virStorageSourcePtr src);
+int qemuDomainStorageSourceChainAccessRevoke(virQEMUDriverPtr driver,
+                                             virDomainObjPtr vm,
+                                             virStorageSourcePtr src);
+
+void qemuDomainStorageSourceAccessRevoke(virQEMUDriverPtr driver,
+                                         virDomainObjPtr vm,
+                                         virStorageSourcePtr elem);
+int qemuDomainStorageSourceAccessAllow(virQEMUDriverPtr driver,
+                                       virDomainObjPtr vm,
+                                       virStorageSourcePtr elem,
+                                       bool readonly,
+                                       bool newSource);
 
 int qemuDomainCleanupAdd(virDomainObjPtr vm,
                          qemuDomainCleanupCallback cb);
