@@ -157,6 +157,7 @@ static int
 virNetLibsshSessionOnceInit(void)
 {
     const char *dbgLevelStr;
+    int dbgLevel;
 
     if (!VIR_CLASS_NEW(virNetLibsshSession, virClassForObjectLockable()))
         return -1;
@@ -172,10 +173,9 @@ virNetLibsshSessionOnceInit(void)
 #endif
 
     dbgLevelStr = virGetEnvAllowSUID("LIBVIRT_LIBSSH_DEBUG");
-    if (dbgLevelStr) {
-        int dbgLevel = virParseNumber(&dbgLevelStr);
+    if (dbgLevelStr &&
+        virStrToLong_i(dbgLevelStr, NULL, 10, &dbgLevel) >= 0)
         ssh_set_log_level(dbgLevel);
-    }
 
     return 0;
 }
@@ -605,49 +605,41 @@ static int
 virNetLibsshAuthenticatePassword(virNetLibsshSessionPtr sess,
                                  virNetLibsshAuthMethodPtr priv)
 {
-    char *password = NULL;
     const char *errmsg;
-    int ret = -1;
+    int rc = SSH_AUTH_ERROR;
 
     VIR_DEBUG("sess=%p", sess);
 
     if (priv->password) {
         /* tunelled password authentication */
-        if ((ret = ssh_userauth_password(sess->session, NULL,
-                                         priv->password)) == 0) {
-            ret = SSH_AUTH_SUCCESS;
-            goto cleanup;
-        }
+        if ((rc = ssh_userauth_password(sess->session, NULL,
+                                        priv->password)) == 0)
+            return SSH_AUTH_SUCCESS;
     } else {
         /* password authentication with interactive password request */
         if (!sess->cred || !sess->cred->cb) {
             virReportError(VIR_ERR_LIBSSH, "%s",
                            _("Can't perform authentication: "
                              "Authentication callback not provided"));
-            ret = SSH_AUTH_ERROR;
-            goto cleanup;
+            return SSH_AUTH_ERROR;
         }
 
         /* Try the authenticating the set amount of times. The server breaks the
          * connection if maximum number of bad auth tries is exceeded */
         while (true) {
+            VIR_AUTODISPOSE_STR password = NULL;
+
             if (!(password = virAuthGetPasswordPath(sess->authPath, sess->cred,
                                                     "ssh", sess->username,
-                                                    sess->hostname))) {
-                ret = SSH_AUTH_ERROR;
-                goto cleanup;
-            }
+                                                    sess->hostname)))
+                return SSH_AUTH_ERROR;
 
             /* tunelled password authentication */
-            if ((ret = ssh_userauth_password(sess->session, NULL,
-                                             password)) == 0) {
-                ret = SSH_AUTH_SUCCESS;
-                goto cleanup;
-            }
+            if ((rc = ssh_userauth_password(sess->session, NULL,
+                                            password)) == 0)
+                return SSH_AUTH_SUCCESS;
 
-            VIR_DISPOSE_STRING(password);
-
-            if (ret != SSH_AUTH_DENIED)
+            if (rc != SSH_AUTH_DENIED)
                 break;
         }
     }
@@ -656,12 +648,7 @@ virNetLibsshAuthenticatePassword(virNetLibsshSessionPtr sess,
     errmsg = ssh_get_error(sess->session);
     virReportError(VIR_ERR_AUTH_FAILED,
                    _("authentication failed: %s"), errmsg);
-
-    return ret;
-
- cleanup:
-    VIR_DISPOSE_STRING(password);
-    return ret;
+    return rc;
 }
 
 /* perform keyboard interactive authentication
@@ -1052,7 +1039,7 @@ virNetLibsshSessionAuthAddPrivKeyAuth(virNetLibsshSessionPtr sess,
 {
     int ret;
     virNetLibsshAuthMethodPtr auth;
-    char *pass = NULL;
+    VIR_AUTODISPOSE_STR pass = NULL;
     char *file = NULL;
 
     if (!keyfile) {
@@ -1076,7 +1063,7 @@ virNetLibsshSessionAuthAddPrivKeyAuth(virNetLibsshSessionPtr sess,
         goto error;
     }
 
-    auth->password = pass;
+    VIR_STEAL_PTR(auth->password, pass);
     auth->filename = file;
     auth->method = VIR_NET_LIBSSH_AUTH_PRIVKEY;
     auth->ssh_flags = SSH_AUTH_METHOD_PUBLICKEY;
@@ -1088,7 +1075,6 @@ virNetLibsshSessionAuthAddPrivKeyAuth(virNetLibsshSessionPtr sess,
     return ret;
 
  error:
-    VIR_DISPOSE_STRING(pass);
     VIR_FREE(file);
     goto cleanup;
 }
