@@ -17,12 +17,10 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library.  If not, see
  * <http://www.gnu.org/licenses/>.
- *
- * Author: Daniel P. Berrange <berrange@redhat.com>
  */
 
-#ifndef __VIR_NET_SOCKET_H__
-# define __VIR_NET_SOCKET_H__
+#ifndef LIBVIRT_VIRNETSOCKET_H
+# define LIBVIRT_VIRNETSOCKET_H
 
 # include "virsocketaddr.h"
 # include "vircommand.h"
@@ -187,4 +185,4 @@ void virNetSocketRemoveIOCallback(virNetSocketPtr sock);
 void virNetSocketClose(virNetSocketPtr sock);
 
 
-#endif /* __VIR_NET_SOCKET_H__ */
+#endif /* LIBVIRT_VIRNETSOCKET_H */
