@@ -92,7 +92,7 @@ virStorageDriverLoadBackendModule(const char *name,
     if (!(modfile = virFileFindResourceFull(name,
                                             "libvirt_storage_backend_",
                                             ".so",
-                                            abs_topbuilddir "/src/.libs",
+                                            abs_top_builddir "/src/.libs",
                                             STORAGE_BACKEND_MODULE_DIR,
                                             "LIBVIRT_STORAGE_BACKEND_DIR")))
         return -1;
@@ -182,3 +182,19 @@ virStorageBackendForType(int type)
                    type, NULLSTR(virStoragePoolTypeToString(type)));
     return NULL;
 }
+
+
+virCapsPtr
+virStorageBackendGetCapabilities(void)
+{
+    virCapsPtr caps;
+    size_t i;
+
+    if (!(caps = virCapabilitiesNew(VIR_ARCH_NONE, false, false)))
+        return NULL;
+
+    for (i = 0; i < virStorageBackendsCount; i++)
+        virCapabilitiesAddStoragePool(caps, virStorageBackends[i]->type);
+
+    return caps;
+}
