@@ -130,27 +130,20 @@ static int
 virStorageBackendISCSIFindLUs(virStoragePoolObjPtr pool,
                               const char *session)
 {
-    char *sysfs_path;
-    int retval = -1;
     uint32_t host;
+    VIR_AUTOFREE(char *) sysfs_path = NULL;
 
     if (virAsprintf(&sysfs_path,
                     "/sys/class/iscsi_session/session%s/device", session) < 0)
-        goto cleanup;
+        return -1;
 
     if (virStorageBackendISCSIGetHostNumber(sysfs_path, &host) < 0)
-        goto cleanup;
+        return -1;
 
     if (virStorageBackendSCSIFindLUs(pool, host) < 0)
-        goto cleanup;
+        return -1;
 
-    retval = 0;
-
- cleanup:
-
-    VIR_FREE(sysfs_path);
-
-    return retval;
+    return 0;
 }
 
 
@@ -158,7 +151,6 @@ static char *
 virStorageBackendISCSIFindPoolSources(const char *srcSpec,
                                       unsigned int flags)
 {
-    virStoragePoolSourcePtr source = NULL;
     size_t ntargets = 0;
     char **targets = NULL;
     char *ret = NULL;
@@ -168,7 +160,8 @@ virStorageBackendISCSIFindPoolSources(const char *srcSpec,
         .nsources = 0,
         .sources = NULL
     };
-    char *portal = NULL;
+    VIR_AUTOFREE(char *) portal = NULL;
+    VIR_AUTOPTR(virStoragePoolSource) source = NULL;
 
     virCheckFlags(0, NULL);
 
@@ -226,8 +219,6 @@ virStorageBackendISCSIFindPoolSources(const char *srcSpec,
     for (i = 0; i < ntargets; i++)
         VIR_FREE(targets[i]);
     VIR_FREE(targets);
-    VIR_FREE(portal);
-    virStoragePoolSourceFree(source);
     return ret;
 }
 
@@ -236,8 +227,8 @@ virStorageBackendISCSICheckPool(virStoragePoolObjPtr pool,
                                 bool *isActive)
 {
     virStoragePoolDefPtr def = virStoragePoolObjGetDef(pool);
-    char *session = NULL;
     int ret = -1;
+    VIR_AUTOFREE(char *) session = NULL;
 
     *isActive = false;
 
@@ -260,10 +251,8 @@ virStorageBackendISCSICheckPool(virStoragePoolObjPtr pool,
         return -1;
     }
 
-    if ((session = virStorageBackendISCSISession(pool, true)) != NULL) {
+    if ((session = virStorageBackendISCSISession(pool, true)))
         *isActive = true;
-        VIR_FREE(session);
-    }
     ret = 0;
 
     return ret;
@@ -331,9 +320,8 @@ static int
 virStorageBackendISCSIStartPool(virStoragePoolObjPtr pool)
 {
     virStoragePoolDefPtr def = virStoragePoolObjGetDef(pool);
-    char *portal = NULL;
-    char *session = NULL;
-    int ret = -1;
+    VIR_AUTOFREE(char *) portal = NULL;
+    VIR_AUTOFREE(char *) session = NULL;
 
     if (def->source.nhost != 1) {
         virReportError(VIR_ERR_CONFIG_UNSUPPORTED, "%s",
@@ -356,50 +344,40 @@ virStorageBackendISCSIStartPool(virStoragePoolObjPtr pool)
 
     if ((session = virStorageBackendISCSISession(pool, true)) == NULL) {
         if ((portal = virStorageBackendISCSIPortal(&def->source)) == NULL)
-            goto cleanup;
+            return -1;
 
         /* Create a static node record for the IQN target. Must be done
          * in order for login to the target */
         if (virISCSINodeNew(portal, def->source.devices[0].path) < 0)
-            goto cleanup;
+            return -1;
 
         if (virStorageBackendISCSISetAuth(portal, &def->source) < 0)
-            goto cleanup;
+            return -1;
 
         if (virISCSIConnectionLogin(portal,
                                     def->source.initiator.iqn,
                                     def->source.devices[0].path) < 0)
-            goto cleanup;
+            return -1;
     }
-    ret = 0;
-
- cleanup:
-    VIR_FREE(portal);
-    VIR_FREE(session);
-    return ret;
+    return 0;
 }
 
 static int
 virStorageBackendISCSIRefreshPool(virStoragePoolObjPtr pool)
 {
     virStoragePoolDefPtr def = virStoragePoolObjGetDef(pool);
-    char *session = NULL;
+    VIR_AUTOFREE(char *) session = NULL;
 
     def->allocation = def->capacity = def->available = 0;
 
     if ((session = virStorageBackendISCSISession(pool, false)) == NULL)
-        goto cleanup;
+        return -1;
     if (virISCSIRescanLUNs(session) < 0)
-        goto cleanup;
+        return -1;
     if (virStorageBackendISCSIFindLUs(pool, session) < 0)
-        goto cleanup;
-    VIR_FREE(session);
+        return -1;
 
     return 0;
-
- cleanup:
-    VIR_FREE(session);
-    return -1;
 }
 
 
@@ -407,13 +385,11 @@ static int
 virStorageBackendISCSIStopPool(virStoragePoolObjPtr pool)
 {
     virStoragePoolDefPtr def = virStoragePoolObjGetDef(pool);
-    char *portal;
-    char *session;
-    int ret = -1;
+    VIR_AUTOFREE(char *) portal = NULL;
+    VIR_AUTOFREE(char *) session = NULL;
 
     if ((session = virStorageBackendISCSISession(pool, true)) == NULL)
         return 0;
-    VIR_FREE(session);
 
     if ((portal = virStorageBackendISCSIPortal(&def->source)) == NULL)
         return -1;
@@ -421,12 +397,9 @@ virStorageBackendISCSIStopPool(virStoragePoolObjPtr pool)
     if (virISCSIConnectionLogout(portal,
                                  def->source.initiator.iqn,
                                  def->source.devices[0].path) < 0)
-        goto cleanup;
-    ret = 0;
+        return -1;
 
- cleanup:
-    VIR_FREE(portal);
-    return ret;
+    return 0;
 }
 
 virStorageBackend virStorageBackendISCSI = {
