@@ -62,7 +62,8 @@ VIR_LOG_INIT("util.cgroup");
 #define CGROUP_NB_TOTAL_CPU_STAT_PARAM 3
 #define CGROUP_NB_PER_CPU_STAT_PARAM   1
 
-VIR_ENUM_IMPL(virCgroupController, VIR_CGROUP_CONTROLLER_LAST,
+VIR_ENUM_IMPL(virCgroupController,
+              VIR_CGROUP_CONTROLLER_LAST,
               "cpu", "cpuacct", "cpuset", "memory", "devices",
               "freezer", "blkio", "net_cls", "perf_event",
               "name=systemd",
@@ -1278,33 +1279,6 @@ virCgroupNewIgnoreError(void)
 }
 
 
-/**
- * virCgroupFree:
- *
- * @group: The group structure to free
- */
-void
-virCgroupFree(virCgroupPtr *group)
-{
-    size_t i;
-
-    if (*group == NULL)
-        return;
-
-    for (i = 0; i < VIR_CGROUP_CONTROLLER_LAST; i++) {
-        VIR_FREE((*group)->legacy[i].mountPoint);
-        VIR_FREE((*group)->legacy[i].linkPoint);
-        VIR_FREE((*group)->legacy[i].placement);
-    }
-
-    VIR_FREE((*group)->unified.mountPoint);
-    VIR_FREE((*group)->unified.placement);
-
-    VIR_FREE((*group)->path);
-    VIR_FREE(*group);
-}
-
-
 /**
  * virCgroupHasController: query whether a cgroup controller is present
  *
@@ -2916,14 +2890,6 @@ virCgroupNewIgnoreError(void)
 }
 
 
-void
-virCgroupFree(virCgroupPtr *group ATTRIBUTE_UNUSED)
-{
-    virReportSystemError(ENXIO, "%s",
-                         _("Control groups not supported on this platform"));
-}
-
-
 bool
 virCgroupHasController(virCgroupPtr cgroup ATTRIBUTE_UNUSED,
                        int controller ATTRIBUTE_UNUSED)
@@ -3564,6 +3530,33 @@ virCgroupControllerAvailable(int controller ATTRIBUTE_UNUSED)
 #endif /* !__linux__ */
 
 
+/**
+ * virCgroupFree:
+ *
+ * @group: The group structure to free
+ */
+void
+virCgroupFree(virCgroupPtr *group)
+{
+    size_t i;
+
+    if (*group == NULL)
+        return;
+
+    for (i = 0; i < VIR_CGROUP_CONTROLLER_LAST; i++) {
+        VIR_FREE((*group)->legacy[i].mountPoint);
+        VIR_FREE((*group)->legacy[i].linkPoint);
+        VIR_FREE((*group)->legacy[i].placement);
+    }
+
+    VIR_FREE((*group)->unified.mountPoint);
+    VIR_FREE((*group)->unified.placement);
+
+    VIR_FREE((*group)->path);
+    VIR_FREE(*group);
+}
+
+
 int
 virCgroupDelThread(virCgroupPtr cgroup,
                    virCgroupThreadName nameval,
