@@ -39,6 +39,7 @@
 #include "virstring.h"
 #include "virsystemd.h"
 #include "virerror.h"
+#include "viralloc.h"
 
 VIR_LOG_INIT("util.cgroup");
 
@@ -46,7 +47,8 @@ VIR_LOG_INIT("util.cgroup");
 
 
 VIR_ENUM_DECL(virCgroupV1Controller);
-VIR_ENUM_IMPL(virCgroupV1Controller, VIR_CGROUP_CONTROLLER_LAST,
+VIR_ENUM_IMPL(virCgroupV1Controller,
+              VIR_CGROUP_CONTROLLER_LAST,
               "cpu", "cpuacct", "cpuset", "memory", "devices",
               "freezer", "blkio", "net_cls", "perf_event",
               "name=systemd",
