@@ -65,7 +65,8 @@ struct _virConfParserCtxt {
   do { while ((ctxt->cur < ctxt->end) && (c_isblank(CUR))) \
           ctxt->cur++; } while (0)
 
-VIR_ENUM_IMPL(virConf, VIR_CONF_LAST,
+VIR_ENUM_IMPL(virConf,
+              VIR_CONF_LAST,
               "*unexpected*",
               "long",
               "unsigned long",
