@@ -21,8 +21,8 @@
  * based on iptables.h
  */
 
-#ifndef __DNSMASQ_H__
-# define __DNSMASQ_H__
+#ifndef LIBVIRT_VIRDNSMASQ_H
+# define LIBVIRT_VIRDNSMASQ_H
 
 # include "virobject.h"
 # include "virsocketaddr.h"
@@ -119,4 +119,4 @@ unsigned long dnsmasqCapsGetVersion(dnsmasqCapsPtr caps);
     (dnsmasqCapsGetVersion(CAPS) >= \
      (DNSMASQ_RA_MAJOR_REQD * 1000000) + \
      (DNSMASQ_RA_MINOR_REQD * 1000))
-#endif /* __DNSMASQ_H__ */
+#endif /* LIBVIRT_VIRDNSMASQ_H */
