@@ -23,7 +23,7 @@
 # define LIBVIRT_VIRERROR_H
 
 # include "internal.h"
-# include "viralloc.h"
+# include "virautoclean.h"
 
 # define VIR_ERROR_MAX_LENGTH 1024
 
