@@ -22,7 +22,8 @@
 # include "internal.h"
 # include "virobject.h"
 # include "virutil.h"
-# include "viralloc.h"
+# include "virautoclean.h"
+# include "virenum.h"
 
 typedef enum {
     VIR_MDEV_MODEL_TYPE_VFIO_PCI = 0,
