@@ -26,7 +26,8 @@
 # include "virmacaddr.h"
 # include "virpci.h"
 # include "virnetdevvlan.h"
-# include "viralloc.h"
+# include "virautoclean.h"
+# include "virenum.h"
 
 # ifdef HAVE_STRUCT_IFREQ
 typedef struct ifreq virIfreq;
