@@ -32,7 +32,8 @@
 
 #define VIR_FROM_THIS VIR_FROM_NET
 
-VIR_ENUM_IMPL(virNetDevMacVLanMode, VIR_NETDEV_MACVLAN_MODE_LAST,
+VIR_ENUM_IMPL(virNetDevMacVLanMode,
+              VIR_NETDEV_MACVLAN_MODE_LAST,
               "vepa",
               "private",
               "bridge",
