@@ -38,6 +38,7 @@
 #include "virkmod.h"
 #include "virstring.h"
 #include "virutil.h"
+#include "viralloc.h"
 
 VIR_LOG_INIT("util.pci");
 
@@ -45,18 +46,21 @@ VIR_LOG_INIT("util.pci");
 #define PCI_ID_LEN 10   /* "XXXX XXXX" */
 #define PCI_ADDR_LEN 13 /* "XXXX:XX:XX.X" */
 
-VIR_ENUM_IMPL(virPCIELinkSpeed, VIR_PCIE_LINK_SPEED_LAST,
+VIR_ENUM_IMPL(virPCIELinkSpeed,
+              VIR_PCIE_LINK_SPEED_LAST,
               "", "2.5", "5", "8", "16",
 );
 
-VIR_ENUM_IMPL(virPCIStubDriver, VIR_PCI_STUB_DRIVER_LAST,
+VIR_ENUM_IMPL(virPCIStubDriver,
+              VIR_PCI_STUB_DRIVER_LAST,
               "none",
               "pciback", /* XEN */
               "pci-stub", /* KVM */
               "vfio-pci", /* VFIO */
 );
 
-VIR_ENUM_IMPL(virPCIHeader, VIR_PCI_HEADER_LAST,
+VIR_ENUM_IMPL(virPCIHeader,
+              VIR_PCI_HEADER_LAST,
               "endpoint",
               "pci-bridge",
               "cardbus-bridge",
