@@ -25,7 +25,8 @@
 # include "virmdev.h"
 # include "virobject.h"
 # include "virutil.h"
-# include "viralloc.h"
+# include "virautoclean.h"
+# include "virenum.h"
 
 typedef struct _virPCIDevice virPCIDevice;
 typedef virPCIDevice *virPCIDevicePtr;
