@@ -23,7 +23,7 @@
 
 # include "internal.h"
 # include "virobject.h"
-# include "viralloc.h"
+# include "virautoclean.h"
 
 typedef struct _virSCSIDevice virSCSIDevice;
 typedef virSCSIDevice *virSCSIDevicePtr;
