@@ -24,7 +24,7 @@
 # include "internal.h"
 # include "virobject.h"
 # include "virutil.h"
-# include "viralloc.h"
+# include "virautoclean.h"
 
 typedef struct _virSCSIVHostDevice virSCSIVHostDevice;
 typedef virSCSIVHostDevice *virSCSIVHostDevicePtr;
