@@ -31,7 +31,8 @@
 
 #define VIR_FROM_THIS VIR_FROM_NONE
 
-VIR_ENUM_IMPL(virTypedParameter, VIR_TYPED_PARAM_LAST,
+VIR_ENUM_IMPL(virTypedParameter,
+              VIR_TYPED_PARAM_LAST,
               "unknown",
               "int",
               "uint",
