@@ -20,11 +20,8 @@
 
 #include <config.h>
 
-#include <stdio.h>
 #include <unistd.h>
-#include <stdlib.h>
 #include <fcntl.h>
-#include <string.h>
 #include <sys/stat.h>
 
 #include "internal.h"
