@@ -35,8 +35,6 @@
 
 # define VIR_FROM_THIS VIR_FROM_NONE
 
-static const char *abs_top_srcdir;
-
 # ifdef __linux__
 #  define RULESTYPE "linux"
 # else
@@ -459,10 +457,6 @@ mymain(void)
 {
     int ret = 0;
 
-    abs_top_srcdir = getenv("abs_top_srcdir");
-    if (!abs_top_srcdir)
-        abs_top_srcdir = abs_srcdir "/..";
-
 # define DO_TEST(name) \
     do { \
         static struct testInfo info = { \
