@@ -46,7 +46,12 @@ testKModConfig(const void *args ATTRIBUTE_UNUSED)
      */
     outbuf = virKModConfig();
     if (!outbuf) {
-        fprintf(stderr, "Failed to get config\n");
+        if (virFileIsExecutable(MODPROBE)) {
+            fprintf(stderr, "Failed to get config\n");
+        } else {
+            /* modprobe doesn't exist, do not claim error. */
+            ret = 0;
+        }
         goto cleanup;
     }
     ret = 0;
