@@ -58,7 +58,7 @@
  *
  * The @flags contains a .completer_flags value defined for each
  * use or 0 if no .completer_flags were specified. If a completer
- * is generic enough @flags can be used to alter it's behaviour.
+ * is generic enough @flags can be used to alter its behaviour.
  * For instance, a completer to fetch names of domains can use
  * @flags to return names of only domains in a particular state
  * that the command accepts.
@@ -79,6 +79,7 @@ virshDomainNameCompleter(vshControl *ctl,
     int ndomains = 0;
     size_t i = 0;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(VIR_CONNECT_LIST_DOMAINS_ACTIVE |
                   VIR_CONNECT_LIST_DOMAINS_INACTIVE |
@@ -95,29 +96,23 @@ virshDomainNameCompleter(vshControl *ctl,
     if ((ndomains = virConnectListAllDomains(priv->conn, &domains, flags)) < 0)
         return NULL;
 
-    if (VIR_ALLOC_N(ret, ndomains + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, ndomains + 1) < 0)
+        goto cleanup;
 
     for (i = 0; i < ndomains; i++) {
         const char *name = virDomainGetName(domains[i]);
 
-        if (VIR_STRDUP(ret[i], name) < 0)
-            goto error;
-
-        virshDomainFree(domains[i]);
+        if (VIR_STRDUP(tmp[i], name) < 0)
+            goto cleanup;
     }
-    VIR_FREE(domains);
 
-    return ret;
+    VIR_STEAL_PTR(ret, tmp);
 
- error:
-    for (; i < ndomains; i++)
+ cleanup:
+    for (i = 0; i < ndomains; i++)
         virshDomainFree(domains[i]);
     VIR_FREE(domains);
-    for (i = 0; i < ndomains; i++)
-        VIR_FREE(ret[i]);
-    VIR_FREE(ret);
-    return NULL;
+    return ret;
 }
 
 
@@ -127,14 +122,14 @@ virshDomainInterfaceCompleter(vshControl *ctl,
                               unsigned int flags)
 {
     virshControlPtr priv = ctl->privData;
-    xmlDocPtr xmldoc = NULL;
-    xmlXPathContextPtr ctxt = NULL;
+    VIR_AUTOPTR(xmlDoc) xmldoc = NULL;
+    VIR_AUTOPTR(xmlXPathContext) ctxt = NULL;
     int ninterfaces;
-    xmlNodePtr *interfaces = NULL;
+    VIR_AUTOFREE(xmlNodePtr *) interfaces = NULL;
     size_t i;
     unsigned int domainXMLFlags = 0;
     char **ret = NULL;
-    char **tmp = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(VIRSH_DOMAIN_INTERFACE_COMPLETER_MAC, NULL);
 
@@ -145,14 +140,14 @@ virshDomainInterfaceCompleter(vshControl *ctl,
         domainXMLFlags = VIR_DOMAIN_XML_INACTIVE;
 
     if (virshDomainGetXML(ctl, cmd, domainXMLFlags, &xmldoc, &ctxt) < 0)
-        goto cleanup;
+        return NULL;
 
     ninterfaces = virXPathNodeSet("./devices/interface", ctxt, &interfaces);
     if (ninterfaces < 0)
-        goto cleanup;
+        return NULL;
 
     if (VIR_ALLOC_N(tmp, ninterfaces + 1) < 0)
-        goto cleanup;
+        return NULL;
 
     for (i = 0; i < ninterfaces; i++) {
         ctxt->node = interfaces[i];
@@ -164,15 +159,10 @@ virshDomainInterfaceCompleter(vshControl *ctl,
         /* In case we are dealing with inactive domain XML there's no
          * <target dev=''/>. Offer MAC addresses then. */
         if (!(tmp[i] = virXPathString("string(./mac/@address)", ctxt)))
-            goto cleanup;
+            return NULL;
     }
 
     VIR_STEAL_PTR(ret, tmp);
- cleanup:
-    VIR_FREE(interfaces);
-    xmlFreeDoc(xmldoc);
-    xmlXPathFreeContext(ctxt);
-    virStringListFree(tmp);
     return ret;
 }
 
@@ -183,12 +173,12 @@ virshDomainDiskTargetCompleter(vshControl *ctl,
                                unsigned int flags)
 {
     virshControlPtr priv = ctl->privData;
-    xmlDocPtr xmldoc = NULL;
-    xmlXPathContextPtr ctxt = NULL;
-    xmlNodePtr *disks = NULL;
+    VIR_AUTOPTR(xmlDoc) xmldoc = NULL;
+    VIR_AUTOPTR(xmlXPathContext) ctxt = NULL;
+    VIR_AUTOFREE(xmlNodePtr *) disks = NULL;
     int ndisks;
     size_t i;
-    char **tmp = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
     char **ret = NULL;
 
     virCheckFlags(0, NULL);
@@ -197,27 +187,22 @@ virshDomainDiskTargetCompleter(vshControl *ctl,
         return NULL;
 
     if (virshDomainGetXML(ctl, cmd, 0, &xmldoc, &ctxt) < 0)
-        goto cleanup;
+        return NULL;
 
     ndisks = virXPathNodeSet("./devices/disk", ctxt, &disks);
     if (ndisks < 0)
-        goto cleanup;
+        return NULL;
 
     if (VIR_ALLOC_N(tmp, ndisks + 1) < 0)
-        goto cleanup;
+        return NULL;
 
     for (i = 0; i < ndisks; i++) {
         ctxt->node = disks[i];
         if (!(tmp[i] = virXPathString("string(./target/@dev)", ctxt)))
-            goto cleanup;
+            return NULL;
     }
 
     VIR_STEAL_PTR(ret, tmp);
- cleanup:
-    VIR_FREE(disks);
-    xmlFreeDoc(xmldoc);
-    xmlXPathFreeContext(ctxt);
-    virStringListFree(tmp);
     return ret;
 }
 
@@ -232,6 +217,7 @@ virshStoragePoolNameCompleter(vshControl *ctl,
     int npools = 0;
     size_t i = 0;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(VIR_CONNECT_LIST_STORAGE_POOLS_INACTIVE |
                   VIR_CONNECT_LIST_STORAGE_POOLS_ACTIVE |
@@ -244,29 +230,23 @@ virshStoragePoolNameCompleter(vshControl *ctl,
     if ((npools = virConnectListAllStoragePools(priv->conn, &pools, flags)) < 0)
         return NULL;
 
-    if (VIR_ALLOC_N(ret, npools + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, npools + 1) < 0)
+        goto cleanup;
 
     for (i = 0; i < npools; i++) {
         const char *name = virStoragePoolGetName(pools[i]);
 
-        if (VIR_STRDUP(ret[i], name) < 0)
-            goto error;
-
-        virStoragePoolFree(pools[i]);
+        if (VIR_STRDUP(tmp[i], name) < 0)
+            goto cleanup;
     }
-    VIR_FREE(pools);
 
-    return ret;
+    VIR_STEAL_PTR(ret, tmp);
 
- error:
-    for (; i < npools; i++)
+ cleanup:
+    for (i = 0; i < npools; i++)
         virStoragePoolFree(pools[i]);
     VIR_FREE(pools);
-    for (i = 0; i < npools; i++)
-        VIR_FREE(ret[i]);
-    VIR_FREE(ret);
-    return NULL;
+    return ret;
 }
 
 
@@ -282,6 +262,7 @@ virshStorageVolNameCompleter(vshControl *ctl,
     int nvols = 0;
     size_t i = 0;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(0, NULL);
 
@@ -292,34 +273,27 @@ virshStorageVolNameCompleter(vshControl *ctl,
         return NULL;
 
     if ((rc = virStoragePoolListAllVolumes(pool, &vols, flags)) < 0)
-        goto error;
+        goto cleanup;
     nvols = rc;
 
-    if (VIR_ALLOC_N(ret, nvols + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, nvols + 1) < 0)
+        goto cleanup;
 
     for (i = 0; i < nvols; i++) {
         const char *name = virStorageVolGetName(vols[i]);
 
-        if (VIR_STRDUP(ret[i], name) < 0)
-            goto error;
-
-        virStorageVolFree(vols[i]);
+        if (VIR_STRDUP(tmp[i], name) < 0)
+            goto cleanup;
     }
-    VIR_FREE(vols);
+
+    VIR_STEAL_PTR(ret, tmp);
+
+ cleanup:
     virStoragePoolFree(pool);
-
-    return ret;
-
- error:
-    for (; i < nvols; i++)
+    for (i = 0; i < nvols; i++)
         virStorageVolFree(vols[i]);
     VIR_FREE(vols);
-    for (i = 0; i < nvols; i++)
-        VIR_FREE(ret[i]);
-    VIR_FREE(ret);
-    virStoragePoolFree(pool);
-    return NULL;
+    return ret;
 }
 
 
@@ -333,6 +307,7 @@ virshInterfaceNameCompleter(vshControl *ctl,
     int nifaces = 0;
     size_t i = 0;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(VIR_CONNECT_LIST_INTERFACES_ACTIVE |
                   VIR_CONNECT_LIST_INTERFACES_INACTIVE,
@@ -344,29 +319,23 @@ virshInterfaceNameCompleter(vshControl *ctl,
     if ((nifaces = virConnectListAllInterfaces(priv->conn, &ifaces, flags)) < 0)
         return NULL;
 
-    if (VIR_ALLOC_N(ret, nifaces + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, nifaces + 1) < 0)
+        goto cleanup;
 
     for (i = 0; i < nifaces; i++) {
         const char *name = virInterfaceGetName(ifaces[i]);
 
-        if (VIR_STRDUP(ret[i], name) < 0)
-            goto error;
-
-        virInterfaceFree(ifaces[i]);
+        if (VIR_STRDUP(tmp[i], name) < 0)
+            goto cleanup;
     }
-    VIR_FREE(ifaces);
 
-    return ret;
+    VIR_STEAL_PTR(ret, tmp);
 
- error:
-    for (; i < nifaces; i++)
+ cleanup:
+    for (i = 0; i < nifaces; i++)
         virInterfaceFree(ifaces[i]);
     VIR_FREE(ifaces);
-    for (i = 0; i < nifaces; i++)
-        VIR_FREE(ret[i]);
-    VIR_FREE(ret);
-    return NULL;
+    return ret;
 }
 
 
@@ -380,6 +349,7 @@ virshNetworkNameCompleter(vshControl *ctl,
     int nnets = 0;
     size_t i = 0;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(VIR_CONNECT_LIST_NETWORKS_INACTIVE |
                   VIR_CONNECT_LIST_NETWORKS_ACTIVE |
@@ -392,29 +362,23 @@ virshNetworkNameCompleter(vshControl *ctl,
     if ((nnets = virConnectListAllNetworks(priv->conn, &nets, flags)) < 0)
         return NULL;
 
-    if (VIR_ALLOC_N(ret, nnets + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, nnets + 1) < 0)
+        goto cleanup;
 
     for (i = 0; i < nnets; i++) {
         const char *name = virNetworkGetName(nets[i]);
 
-        if (VIR_STRDUP(ret[i], name) < 0)
-            goto error;
-
-        virNetworkFree(nets[i]);
+        if (VIR_STRDUP(tmp[i], name) < 0)
+            goto cleanup;
     }
-    VIR_FREE(nets);
 
-    return ret;
+    VIR_STEAL_PTR(ret, tmp);
 
- error:
-    for (; i < nnets; i++)
+ cleanup:
+    for (i = 0; i < nnets; i++)
         virNetworkFree(nets[i]);
     VIR_FREE(nets);
-    for (i = 0; i < nnets; i++)
-        VIR_FREE(ret[i]);
-    VIR_FREE(ret);
-    return NULL;
+    return ret;
 }
 
 
@@ -425,22 +389,22 @@ virshNetworkEventNameCompleter(vshControl *ctl ATTRIBUTE_UNUSED,
 {
     size_t i = 0;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(0, NULL);
 
-    if (VIR_ALLOC_N(ret, VIR_NETWORK_EVENT_ID_LAST + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, VIR_NETWORK_EVENT_ID_LAST + 1) < 0)
+        goto cleanup;
 
     for (i = 0; i < VIR_NETWORK_EVENT_ID_LAST; i++) {
-        if (VIR_STRDUP(ret[i], virshNetworkEventCallbacks[i].name) < 0)
-            goto error;
+        if (VIR_STRDUP(tmp[i], virshNetworkEventCallbacks[i].name) < 0)
+            goto cleanup;
     }
 
-    return ret;
+    VIR_STEAL_PTR(ret, tmp);
 
- error:
-    virStringListFree(ret);
-    return NULL;
+ cleanup:
+    return ret;
 }
 
 
@@ -454,6 +418,7 @@ virshNodeDeviceNameCompleter(vshControl *ctl,
     int ndevs = 0;
     size_t i = 0;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(0, NULL);
 
@@ -463,29 +428,23 @@ virshNodeDeviceNameCompleter(vshControl *ctl,
     if ((ndevs = virConnectListAllNodeDevices(priv->conn, &devs, flags)) < 0)
         return NULL;
 
-    if (VIR_ALLOC_N(ret, ndevs + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, ndevs + 1) < 0)
+        goto cleanup;
 
     for (i = 0; i < ndevs; i++) {
         const char *name = virNodeDeviceGetName(devs[i]);
 
-        if (VIR_STRDUP(ret[i], name) < 0)
-            goto error;
-
-        virNodeDeviceFree(devs[i]);
+        if (VIR_STRDUP(tmp[i], name) < 0)
+            goto cleanup;
     }
-    VIR_FREE(devs);
 
-    return ret;
+    VIR_STEAL_PTR(ret, tmp);
 
- error:
-    for (; i < ndevs; i++)
+ cleanup:
+    for (i = 0; i < ndevs; i++)
         virNodeDeviceFree(devs[i]);
     VIR_FREE(devs);
-    for (i = 0; i < ndevs; i++)
-        VIR_FREE(ret[i]);
-    VIR_FREE(ret);
-    return NULL;
+    return ret;
 }
 
 
@@ -499,6 +458,7 @@ virshNWFilterNameCompleter(vshControl *ctl,
     int nnwfilters = 0;
     size_t i = 0;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(0, NULL);
 
@@ -508,29 +468,23 @@ virshNWFilterNameCompleter(vshControl *ctl,
     if ((nnwfilters = virConnectListAllNWFilters(priv->conn, &nwfilters, flags)) < 0)
         return NULL;
 
-    if (VIR_ALLOC_N(ret, nnwfilters + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, nnwfilters + 1) < 0)
+        goto cleanup;
 
     for (i = 0; i < nnwfilters; i++) {
         const char *name = virNWFilterGetName(nwfilters[i]);
 
-        if (VIR_STRDUP(ret[i], name) < 0)
-            goto error;
-
-        virNWFilterFree(nwfilters[i]);
+        if (VIR_STRDUP(tmp[i], name) < 0)
+            goto cleanup;
     }
-    VIR_FREE(nwfilters);
 
-    return ret;
+    VIR_STEAL_PTR(ret, tmp);
 
- error:
-    for (; i < nnwfilters; i++)
+ cleanup:
+    for (i = 0; i < nnwfilters; i++)
         virNWFilterFree(nwfilters[i]);
     VIR_FREE(nwfilters);
-    for (i = 0; i < nnwfilters; i++)
-        VIR_FREE(ret[i]);
-    VIR_FREE(ret);
-    return NULL;
+    return ret;
 }
 
 
@@ -544,6 +498,7 @@ virshNWFilterBindingNameCompleter(vshControl *ctl,
     int nbindings = 0;
     size_t i = 0;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(0, NULL);
 
@@ -553,29 +508,23 @@ virshNWFilterBindingNameCompleter(vshControl *ctl,
     if ((nbindings = virConnectListAllNWFilterBindings(priv->conn, &bindings, flags)) < 0)
         return NULL;
 
-    if (VIR_ALLOC_N(ret, nbindings + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, nbindings + 1) < 0)
+        goto cleanup;
 
     for (i = 0; i < nbindings; i++) {
         const char *name = virNWFilterBindingGetPortDev(bindings[i]);
 
-        if (VIR_STRDUP(ret[i], name) < 0)
-            goto error;
-
-        virNWFilterBindingFree(bindings[i]);
+        if (VIR_STRDUP(tmp[i], name) < 0)
+            goto cleanup;
     }
-    VIR_FREE(bindings);
 
-    return ret;
+    VIR_STEAL_PTR(ret, tmp);
 
- error:
-    for (; i < nbindings; i++)
+ cleanup:
+    for (i = 0; i < nbindings; i++)
         virNWFilterBindingFree(bindings[i]);
     VIR_FREE(bindings);
-    for (i = 0; i < nbindings; i++)
-        VIR_FREE(ret[i]);
-    VIR_FREE(ret);
-    return NULL;
+    return ret;
 }
 
 
@@ -589,6 +538,7 @@ virshSecretUUIDCompleter(vshControl *ctl,
     int nsecrets = 0;
     size_t i = 0;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(0, NULL);
 
@@ -598,30 +548,24 @@ virshSecretUUIDCompleter(vshControl *ctl,
     if ((nsecrets = virConnectListAllSecrets(priv->conn, &secrets, flags)) < 0)
         return NULL;
 
-    if (VIR_ALLOC_N(ret, nsecrets + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, nsecrets + 1) < 0)
+        goto cleanup;
 
     for (i = 0; i < nsecrets; i++) {
         char uuid[VIR_UUID_STRING_BUFLEN];
 
         if (virSecretGetUUIDString(secrets[i], uuid) < 0 ||
-            VIR_STRDUP(ret[i], uuid) < 0)
-            goto error;
-
-        virSecretFree(secrets[i]);
+            VIR_STRDUP(tmp[i], uuid) < 0)
+            goto cleanup;
     }
-    VIR_FREE(secrets);
 
-    return ret;
+    VIR_STEAL_PTR(ret, tmp);
 
- error:
-    for (; i < nsecrets; i++)
+ cleanup:
+    for (i = 0; i < nsecrets; i++)
         virSecretFree(secrets[i]);
     VIR_FREE(secrets);
-    for (i = 0; i < nsecrets; i++)
-        VIR_FREE(ret[i]);
-    VIR_FREE(ret);
-    return NULL;
+    return ret;
 }
 
 
@@ -637,6 +581,7 @@ virshSnapshotNameCompleter(vshControl *ctl,
     int nsnapshots = 0;
     size_t i = 0;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(0, NULL);
 
@@ -647,34 +592,49 @@ virshSnapshotNameCompleter(vshControl *ctl,
         return NULL;
 
     if ((rc = virDomainListAllSnapshots(dom, &snapshots, flags)) < 0)
-        goto error;
+        goto cleanup;
     nsnapshots = rc;
 
-    if (VIR_ALLOC_N(ret, nsnapshots + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, nsnapshots + 1) < 0)
+        goto cleanup;
 
     for (i = 0; i < nsnapshots; i++) {
         const char *name = virDomainSnapshotGetName(snapshots[i]);
 
-        if (VIR_STRDUP(ret[i], name) < 0)
-            goto error;
-
-        virshDomainSnapshotFree(snapshots[i]);
+        if (VIR_STRDUP(tmp[i], name) < 0)
+            goto cleanup;
     }
-    VIR_FREE(snapshots);
+
+    VIR_STEAL_PTR(ret, tmp);
+
+ cleanup:
     virshDomainFree(dom);
-
-    return ret;
-
- error:
-    for (; i < nsnapshots; i++)
+    for (i = 0; i < nsnapshots; i++)
         virshDomainSnapshotFree(snapshots[i]);
     VIR_FREE(snapshots);
-    for (i = 0; i < nsnapshots; i++)
-        VIR_FREE(ret[i]);
-    VIR_FREE(ret);
-    virshDomainFree(dom);
-    return NULL;
+    return ret;
+}
+
+static char *
+virshPagesizeNodeToString(xmlNodePtr node)
+{
+    VIR_AUTOFREE(char *) pagesize = NULL;
+    VIR_AUTOFREE(char *) unit = NULL;
+    unsigned long long byteval = 0;
+    const char *suffix = NULL;
+    double size = 0;
+    char *ret;
+
+    pagesize = virXMLPropString(node, "size");
+    unit = virXMLPropString(node, "unit");
+    if (virStrToLong_ull(pagesize, NULL, 10, &byteval) < 0)
+        return NULL;
+    if (virScaleInteger(&byteval, unit, 1024, UINT_MAX) < 0)
+        return NULL;
+    size = vshPrettyCapacity(byteval, &suffix);
+    if (virAsprintf(&ret, "%.0f%s", size, suffix) < 0)
+        return NULL;
+    return ret;
 }
 
 char **
@@ -682,83 +642,54 @@ virshAllocpagesPagesizeCompleter(vshControl *ctl,
                                  const vshCmd *cmd ATTRIBUTE_UNUSED,
                                  unsigned int flags)
 {
-    unsigned long long byteval = 0;
-    xmlXPathContextPtr ctxt = NULL;
+    VIR_AUTOPTR(xmlXPathContext) ctxt = NULL;
     virshControlPtr priv = ctl->privData;
     unsigned int npages = 0;
-    xmlNodePtr *pages = NULL;
-    xmlDocPtr doc = NULL;
-    double size = 0;
+    VIR_AUTOFREE(xmlNodePtr *) pages = NULL;
+    VIR_AUTOPTR(xmlDoc) doc = NULL;
     size_t i = 0;
-    const char *suffix = NULL;
     const char *cellnum = NULL;
     bool cellno = vshCommandOptBool(cmd, "cellno");
-    char *path = NULL;
-    char *pagesize = NULL;
-    char *cap_xml = NULL;
+    VIR_AUTOFREE(char *) path = NULL;
+    VIR_AUTOFREE(char *) cap_xml = NULL;
     char **ret = NULL;
-    char *unit = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(0, NULL);
 
     if (!priv->conn || virConnectIsAlive(priv->conn) <= 0)
-        goto error;
+        return NULL;
 
     if (!(cap_xml = virConnectGetCapabilities(priv->conn)))
-        goto error;
+        return NULL;
 
     if (!(doc = virXMLParseStringCtxt(cap_xml, _("capabilities"), &ctxt)))
-        goto error;
+        return NULL;
 
     if (cellno && vshCommandOptStringQuiet(ctl, cmd, "cellno", &cellnum) > 0) {
         if (virAsprintf(&path,
                         "/capabilities/host/topology/cells/cell[@id=\"%s\"]/pages",
                         cellnum) < 0)
-            goto error;
+            return NULL;
     } else {
         if (virAsprintf(&path, "/capabilities/host/cpu/pages") < 0)
-            goto error;
+            return NULL;
     }
 
     npages = virXPathNodeSet(path, ctxt, &pages);
     if (npages <= 0)
-        goto error;
+        return NULL;
 
-    if (VIR_ALLOC_N(ret, npages + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, npages + 1) < 0)
+        return NULL;
 
     for (i = 0; i < npages; i++) {
-        VIR_FREE(pagesize);
-        VIR_FREE(unit);
-        pagesize = virXMLPropString(pages[i], "size");
-        unit = virXMLPropString(pages[i], "unit");
-        if (virStrToLong_ull(pagesize, NULL, 10, &byteval) < 0)
-            goto error;
-        if (virScaleInteger(&byteval, unit, 1024, UINT_MAX) < 0)
-            goto error;
-        size = vshPrettyCapacity(byteval, &suffix);
-        if (virAsprintf(&ret[i], "%.0f%s", size, suffix) < 0)
-            goto error;
+        if (!(tmp[i] = virshPagesizeNodeToString(pages[i])))
+            return NULL;
     }
 
- cleanup:
-    xmlXPathFreeContext(ctxt);
-    VIR_FREE(pages);
-    xmlFreeDoc(doc);
-    VIR_FREE(path);
-    VIR_FREE(pagesize);
-    VIR_FREE(cap_xml);
-    VIR_FREE(unit);
-
+    VIR_STEAL_PTR(ret, tmp);
     return ret;
-
- error:
-    if (ret) {
-        for (i = 0; i < npages; i++)
-            VIR_FREE(ret[i]);
-    }
-    VIR_FREE(ret);
-    goto cleanup;
 }
 
 
@@ -769,22 +700,20 @@ virshSecretEventNameCompleter(vshControl *ctl ATTRIBUTE_UNUSED,
 {
     size_t i;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(0, NULL);
 
-    if (VIR_ALLOC_N(ret, VIR_SECRET_EVENT_ID_LAST + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, VIR_SECRET_EVENT_ID_LAST + 1) < 0)
+        return NULL;
 
     for (i = 0; i < VIR_SECRET_EVENT_ID_LAST; i++) {
-        if (VIR_STRDUP(ret[i], virshSecretEventCallbacks[i].name) < 0)
-            goto error;
+        if (VIR_STRDUP(tmp[i], virshSecretEventCallbacks[i].name) < 0)
+            return NULL;
     }
 
+    VIR_STEAL_PTR(ret, tmp);
     return ret;
-
- error:
-    virStringListFree(ret);
-    return NULL;
 }
 
 
@@ -795,22 +724,20 @@ virshDomainEventNameCompleter(vshControl *ctl ATTRIBUTE_UNUSED,
 {
     size_t i = 0;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(0, NULL);
 
-    if (VIR_ALLOC_N(ret, VIR_DOMAIN_EVENT_ID_LAST + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, VIR_DOMAIN_EVENT_ID_LAST + 1) < 0)
+        return NULL;
 
     for (i = 0; i < VIR_DOMAIN_EVENT_ID_LAST; i++) {
-        if (VIR_STRDUP(ret[i], virshDomainEventCallbacks[i].name) < 0)
-            goto error;
+        if (VIR_STRDUP(tmp[i], virshDomainEventCallbacks[i].name) < 0)
+            return NULL;
     }
 
+    VIR_STEAL_PTR(ret, tmp);
     return ret;
-
- error:
-    virStringListFree(ret);
-    return NULL;
 }
 
 
@@ -821,22 +748,20 @@ virshPoolEventNameCompleter(vshControl *ctl ATTRIBUTE_UNUSED,
 {
     size_t i = 0;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(0, NULL);
 
-    if (VIR_ALLOC_N(ret, VIR_STORAGE_POOL_EVENT_ID_LAST + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, VIR_STORAGE_POOL_EVENT_ID_LAST + 1) < 0)
+        return NULL;
 
     for (i = 0; i < VIR_STORAGE_POOL_EVENT_ID_LAST; i++) {
-        if (VIR_STRDUP(ret[i], virshPoolEventCallbacks[i].name) < 0)
-            goto error;
+        if (VIR_STRDUP(tmp[i], virshPoolEventCallbacks[i].name) < 0)
+            return NULL;
     }
 
+    VIR_STEAL_PTR(ret, tmp);
     return ret;
-
- error:
-    virStringListFree(ret);
-    return NULL;
 }
 
 
@@ -848,14 +773,15 @@ virshDomainInterfaceStateCompleter(vshControl *ctl,
     virshControlPtr priv = ctl->privData;
     const char *iface = NULL;
     char **ret = NULL;
-    xmlDocPtr xml = NULL;
-    xmlXPathContextPtr ctxt = NULL;
+    VIR_AUTOPTR(xmlDoc) xml = NULL;
+    VIR_AUTOPTR(xmlXPathContext) ctxt = NULL;
     virMacAddr macaddr;
     char macstr[VIR_MAC_STRING_BUFLEN] = "";
     int ninterfaces;
-    xmlNodePtr *interfaces = NULL;
-    char *xpath = NULL;
-    char *state = NULL;
+    VIR_AUTOFREE(xmlNodePtr *) interfaces = NULL;
+    VIR_AUTOFREE(char *) xpath = NULL;
+    VIR_AUTOFREE(char *) state = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(0, NULL);
 
@@ -863,10 +789,10 @@ virshDomainInterfaceStateCompleter(vshControl *ctl,
         return NULL;
 
     if (virshDomainGetXML(ctl, cmd, flags, &xml, &ctxt) < 0)
-        goto cleanup;
+        return NULL;
 
     if (vshCommandOptStringReq(ctl, cmd, "interface", &iface) < 0)
-        goto cleanup;
+        return NULL;
 
     /* normalize the mac addr */
     if (virMacAddrParse(iface, &macaddr) == 0)
@@ -875,40 +801,30 @@ virshDomainInterfaceStateCompleter(vshControl *ctl,
     if (virAsprintf(&xpath, "/domain/devices/interface[(mac/@address = '%s') or "
                             "                          (target/@dev = '%s')]",
                            macstr, iface) < 0)
-        goto cleanup;
+        return NULL;
 
     if ((ninterfaces = virXPathNodeSet(xpath, ctxt, &interfaces)) < 0)
-        goto cleanup;
+        return NULL;
 
     if (ninterfaces != 1)
-        goto cleanup;
+        return NULL;
 
     ctxt->node = interfaces[0];
 
-    if (VIR_ALLOC_N(ret, 2) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, 2) < 0)
+        return NULL;
 
     if ((state = virXPathString("string(./link/@state)", ctxt)) &&
         STREQ(state, "down")) {
-        if (VIR_STRDUP(ret[0], "up") < 0)
-            goto error;
+        if (VIR_STRDUP(tmp[0], "up") < 0)
+            return NULL;
     } else {
-        if (VIR_STRDUP(ret[0], "down") < 0)
-            goto error;
+        if (VIR_STRDUP(tmp[0], "down") < 0)
+            return NULL;
     }
 
- cleanup:
-    VIR_FREE(state);
-    VIR_FREE(xpath);
-    VIR_FREE(interfaces);
-    xmlXPathFreeContext(ctxt);
-    xmlFreeDoc(xml);
+    VIR_STEAL_PTR(ret, tmp);
     return ret;
-
- error:
-    virStringListFree(ret);
-    ret = NULL;
-    goto cleanup;
 }
 
 
@@ -919,22 +835,20 @@ virshNodedevEventNameCompleter(vshControl *ctl ATTRIBUTE_UNUSED,
 {
     size_t i = 0;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(0, NULL);
 
-    if (VIR_ALLOC_N(ret, VIR_NODE_DEVICE_EVENT_ID_LAST + 1) < 0)
-        goto error;
+    if (VIR_ALLOC_N(tmp, VIR_NODE_DEVICE_EVENT_ID_LAST + 1) < 0)
+        return NULL;
 
     for (i = 0; i < VIR_NODE_DEVICE_EVENT_ID_LAST; i++) {
-        if (VIR_STRDUP(ret[i], virshNodedevEventCallbacks[i].name) < 0)
-            goto error;
+        if (VIR_STRDUP(tmp[i], virshNodedevEventCallbacks[i].name) < 0)
+            return NULL;
     }
 
+    VIR_STEAL_PTR(ret, tmp);
     return ret;
-
- error:
-    virStringListFree(ret);
-    return NULL;
 }
 
 
@@ -943,53 +857,41 @@ virshCellnoCompleter(vshControl *ctl,
                      const vshCmd *cmd ATTRIBUTE_UNUSED,
                      unsigned int flags)
 {
-    xmlXPathContextPtr ctxt = NULL;
+    VIR_AUTOPTR(xmlXPathContext) ctxt = NULL;
     virshControlPtr priv = ctl->privData;
     unsigned int ncells = 0;
-    xmlNodePtr *cells = NULL;
-    xmlDocPtr doc = NULL;
+    VIR_AUTOFREE(xmlNodePtr *) cells = NULL;
+    VIR_AUTOPTR(xmlDoc) doc = NULL;
     size_t i = 0;
-    char *cap_xml = NULL;
+    VIR_AUTOFREE(char *) cap_xml = NULL;
     char **ret = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(0, NULL);
 
     if (!priv->conn || virConnectIsAlive(priv->conn) <= 0)
-        goto error;
+        return NULL;
 
     if (!(cap_xml = virConnectGetCapabilities(priv->conn)))
-        goto error;
+        return NULL;
 
     if (!(doc = virXMLParseStringCtxt(cap_xml, _("capabilities"), &ctxt)))
-        goto error;
+        return NULL;
 
     ncells = virXPathNodeSet("/capabilities/host/topology/cells/cell", ctxt, &cells);
     if (ncells <= 0)
-        goto error;
+        return NULL;
 
-    if (VIR_ALLOC_N(ret, ncells + 1))
-        goto error;
+    if (VIR_ALLOC_N(tmp, ncells + 1))
+        return NULL;
 
     for (i = 0; i < ncells; i++) {
-        if (!(ret[i] = virXMLPropString(cells[i], "id")))
-            goto error;
+        if (!(tmp[i] = virXMLPropString(cells[i], "id")))
+            return NULL;
     }
 
- cleanup:
-    xmlXPathFreeContext(ctxt);
-    VIR_FREE(cells);
-    xmlFreeDoc(doc);
-    VIR_FREE(cap_xml);
-
+    VIR_STEAL_PTR(ret, tmp);
     return ret;
-
- error:
-    if (ret) {
-        for (i = 0; i < ncells; i++)
-            VIR_FREE(ret[i]);
-    }
-    VIR_FREE(ret);
-    goto cleanup;
 }
 
 
@@ -999,14 +901,14 @@ virshDomainDeviceAliasCompleter(vshControl *ctl,
                                 unsigned int flags)
 {
     virshControlPtr priv = ctl->privData;
-    xmlDocPtr xmldoc = NULL;
-    xmlXPathContextPtr ctxt = NULL;
+    VIR_AUTOPTR(xmlDoc) xmldoc = NULL;
+    VIR_AUTOPTR(xmlXPathContext) ctxt = NULL;
     int naliases;
-    xmlNodePtr *aliases = NULL;
+    VIR_AUTOFREE(xmlNodePtr *) aliases = NULL;
     size_t i;
     unsigned int domainXMLFlags = 0;
     char **ret = NULL;
-    char **tmp = NULL;
+    VIR_AUTOSTRINGLIST tmp = NULL;
 
     virCheckFlags(0, NULL);
 
@@ -1017,25 +919,76 @@ virshDomainDeviceAliasCompleter(vshControl *ctl,
         domainXMLFlags = VIR_DOMAIN_XML_INACTIVE;
 
     if (virshDomainGetXML(ctl, cmd, domainXMLFlags, &xmldoc, &ctxt) < 0)
-        goto cleanup;
+        return NULL;
 
     naliases = virXPathNodeSet("./devices//alias/@name", ctxt, &aliases);
     if (naliases < 0)
-        goto cleanup;
+        return NULL;
 
     if (VIR_ALLOC_N(tmp, naliases + 1) < 0)
-        goto cleanup;
+        return NULL;
 
     for (i = 0; i < naliases; i++) {
         if (!(tmp[i] = virXMLNodeContentString(aliases[i])))
-            goto cleanup;
+            return NULL;
+    }
+
+    VIR_STEAL_PTR(ret, tmp);
+    return ret;
+}
+
+
+char **
+virshDomainShutdownModeCompleter(vshControl *ctl,
+                                 const vshCmd *cmd,
+                                 unsigned int flags)
+{
+    const char *modes[] = {"acpi", "agent", "initctl", "signal", "paravirt"};
+    size_t i;
+    char **ret = NULL;
+    size_t ntmp = 0;
+    VIR_AUTOSTRINGLIST tmp = NULL;
+    const char *modeConst = NULL;
+    VIR_AUTOFREE(char *) mode = NULL;
+    VIR_AUTOSTRINGLIST modesSpecified = NULL;
+
+    virCheckFlags(0, NULL);
+
+    if (vshCommandOptStringQuiet(ctl, cmd, "mode", &modeConst) < 0)
+        return NULL;
+
+    if (STREQ_NULLABLE(modeConst, " "))
+        modeConst = NULL;
+
+    if (modeConst) {
+        char *modeTmp = NULL;
+
+        if (VIR_STRDUP(mode, modeConst) < 0)
+            return NULL;
+
+        if ((modeTmp = strrchr(mode, ',')))
+            *modeTmp = '\0';
+        else
+            VIR_FREE(mode);
+    }
+
+    if (mode && !(modesSpecified = virStringSplit(mode, ",", 0)))
+        return NULL;
+
+    if (VIR_ALLOC_N(tmp, ARRAY_CARDINALITY(modes) + 1) < 0)
+        return NULL;
+
+    for (i = 0; i < ARRAY_CARDINALITY(modes); i++) {
+        if (virStringListHasString((const char **)modesSpecified, modes[i]))
+            continue;
+
+        if ((mode && virAsprintf(&tmp[ntmp], "%s,%s", mode, modes[i]) < 0) ||
+            (!mode && VIR_STRDUP(tmp[ntmp], modes[i]) < 0))
+            return NULL;
+
+        ntmp++;
     }
 
     VIR_STEAL_PTR(ret, tmp);
- cleanup:
-    VIR_FREE(aliases);
-    xmlFreeDoc(xmldoc);
-    xmlXPathFreeContext(ctxt);
-    virStringListFree(tmp);
     return ret;
 }
