@@ -34,6 +34,7 @@
 #include "virtypedparam.h"
 #include "virstring.h"
 #include "virfile.h"
+#include "virenum.h"
 
 /*
  * "capabilities" command
@@ -773,7 +774,8 @@ typedef enum {
 } virshCPUStats;
 
 VIR_ENUM_DECL(virshCPUStats);
-VIR_ENUM_IMPL(virshCPUStats, VIRSH_CPU_LAST,
+VIR_ENUM_IMPL(virshCPUStats,
+              VIRSH_CPU_LAST,
               VIR_NODE_CPU_STATS_USER,
               VIR_NODE_CPU_STATS_KERNEL,
               VIR_NODE_CPU_STATS_IDLE,
